@@ -2,34 +2,33 @@ package PPI;
 
 # See POD at end for documentation
 
-use 5.006;
+use 5.005;
 use strict;
 
 # Set the version for CPAN
-our $VERSION = '1.28401'; # TRIAL
-
-our ( $XS_COMPATIBLE, @XS_EXCLUDE ) = ( '0.845' );
+use vars qw{$VERSION $XS_COMPATIBLE @XS_EXCLUDE};
+BEGIN {
+	$VERSION       = '1.001';
+	$XS_COMPATIBLE = '0.845';
+	@XS_EXCLUDE    = ();
+}
 
 # Load everything
-use PPI::Util                 ();
-use PPI::Exception            ();
 use PPI::Element              ();
 use PPI::Token                ();
 use PPI::Statement            ();
 use PPI::Structure            ();
 use PPI::Document             ();
-use PPI::Document::File       ();
-use PPI::Document::Fragment   ();
 use PPI::Document::Normalized ();
 use PPI::Normal               ();
 use PPI::Tokenizer            ();
 use PPI::Lexer                ();
 
 # If it is installed, load in PPI::XS
-die
-  if !$PPI::XS_DISABLE
-  and !eval { require PPI::XS; 1 }
-  and $@ !~ /^Can't locate .*? at /;    # ignore failure to load if not installed
+unless ( $PPI::XS_DISABLE ) {
+	eval { require PPI::XS };
+	die if $@ && $@ !~ /^Can't locate .*? at /; # Only ignore if not installed
+}
 
 1;
 
@@ -49,10 +48,10 @@ PPI - Parse, Analyze and Manipulate Perl (without perl)
   my $Document = PPI::Document->new;
   
   # Create a document from source
-  $Document = PPI::Document->new(\'print "Hello World!\n"');
+  $Document = PPI::Document->new('print "Hello World!\n"');
   
   # Load a Document from a file
-  $Document = PPI::Document->new('Module.pm');
+  $Document = PPI::Document->load('Module.pm');
   
   # Does it contain any POD?
   if ( $Document->find_any('PPI::Token::Pod') ) {
@@ -84,17 +83,17 @@ other than with perl (the application) was one that caused difficulty
 for a long time.
 
 The cause of this problem was Perl's complex and dynamic grammar.
-Although there is typically not a huge diversity in the grammar of most
+Although there are typically not a huge diversity in the grammar of most
 Perl code, certain issues cause large problems when it comes to parsing.
 
-Indeed, quite early in Perl's history Tom Christiansen introduced the Perl
+Indeed, quite early in Perl's history Tom Christenson introduced the Perl
 community to the quote I<"Nothing but perl can parse Perl">, or as it is
-more often stated now as a truism:
+more often stated now:
 
 B<"Only perl can parse Perl">
 
-One example of the sorts of things that prevent Perl from being easily parsed
-is function signatures, as demonstrated by the following.
+One example of the sorts of things the prevent Perl being easily parsed are
+function signatures, as demonstrated by the following.
 
   @result = (dothis $foo, $bar);
   
@@ -113,10 +112,9 @@ the statement being parsed.
 The information might not just be elsewhere in the file, it might not even be
 in the same file at all. It might also not be able to determine this
 information without the prior execution of a C<BEGIN {}> block, or the
-loading and execution of one or more external modules. Or worse the C<&dothis>
-function may not even have been written yet.
+loading and execution of one or more external modules.
 
-B<When parsing Perl as code, you must also execute it.>
+B<When parsing Perl as code, you must also execute it>
 
 Even perl itself never really fully understands the structure of the source
 code after and indeed B<as> it processes it, and in that sense doesn't
@@ -135,26 +133,24 @@ single file containing Perl source code "isolated" from any other
 resources, such as libraries upon which the code may depend, and
 without needing to run an instance of perl alongside or inside the parser.
 
-Historically, using an embedded perl parser was widely considered to be
-the most likely avenue for finding a solution to parsing Perl. It has been
-investigated from time to time, but attempts have generally failed or
-suffered from sufficiently bad corner cases that they were abandoned.
+Historically, using an embedded perl parser was one of the potential
+solutions for C<Parse::Perl> that was investigated from time to time
+and has generally failed or suffered from sufficiently bad corner cases
+that these efforts were abandoned).
 
 =head2 What Does PPI Stand For?
 
 C<PPI> is an acronym for the longer original module name
-C<Parse::Perl::Isolated>. And in the spirit of the silly acronym games
-played by certain unnamed Open Source projects you may have I<hurd> of,
-it is also a reverse backronym of "I Parse Perl".
+C<Parse::Perl::Isolated>. And in the spirit or the silly acronym games
+played by certain unnamed Open Source projects you may have I<heard> of,
+it's also a reverse acronym for "I Parse Perl".
 
 Of course, I could just be lying and have just made that second bit up
 10 minutes before the release of PPI 1.000. Besides, B<all> the cool
 Perl packages have TLAs (Three Letter Acronyms). It's a rule or something.
 
-Why don't you just think of it as the B<Perl Parsing Interface> for simplicity.
-
-The original name was shortened to prevent the author (and you the users)
-from contracting RSI by having to type crazy things like
+The name was shortened to prevent the author (and you the users) from
+contracting RSI by having to type crazy things like
 C<Parse::Perl::Isolated::Token::QuoteLike::Backtick> 100 times a day.
 
 In acknowledgment that someone may some day come up with a valid solution
@@ -163,15 +159,22 @@ to leave the C<Parse::Perl> namespace free for any such effort.
 
 Since that time I've been able to prove to my own satisfaction that it
 B<is> truly impossible to accurately parse Perl as both code and document
-at once. For the academics, parsing Perl suffers from the "Halting Problem".
+at once.
+
+With this in mind C<Parse::Perl> has now been co-opted as the title for
+the SourceForge project that publishes PPI and a large collection of other
+applications and modules related to the (document) parsing of Perl source
+code.
+
+You can find this project at L<http://sf.net/projects/parseperl>.
 
 =head2 Why Parse Perl?
 
 Once you can accept that we will never be able to parse Perl well enough
 to meet the standards of things that treat Perl as code, it is worth
-re-examining I<why> we want to "parse" Perl at all.
+re-examining C<why> we want to "parse" Perl at all.
 
-What are the things that people might want a "Perl parser" for?
+What are the things that people might want a "Perl parser" for.
 
 =over 4
 
@@ -180,9 +183,6 @@ What are the things that people might want a "Perl parser" for?
 Analyzing the contents of a Perl document to automatically generate
 documentation, in parallel to, or as a replacement for, POD documentation.
 
-Allow an indexer to locate and process all the comments and
-documentation from code for "full text search" applications.
-
 =item Structural and Quality Analysis
 
 Determine quality or other metrics across a body of code, and identify
@@ -191,9 +191,6 @@ situations relating to particular phrases, techniques or locations.
 Index functions, variables and packages within Perl code, and doing search
 and graph (in the node/edge sense) analysis of large code bases.
 
-L<Perl::Critic>, based on PPI, is a large, thriving tool for bug detection
-and style analysis of Perl code.
-
 =item Refactoring
 
 Make structural, syntax, or other changes to code in an automated manner,
@@ -204,7 +201,7 @@ or whatever. All the sort of things you'd want from a L<Perl::Editor>.
 =item Layout
 
 Change the layout of code without changing its meaning. This includes
-techniques such as tidying (like L<perltidy>), obfuscation, compressing and
+techniques such as tidying (like L<perltidy>), obfuscation, compressiong and
 "squishing", or to implement formatting preferences or policies.
 
 =item Presentation
@@ -243,65 +240,24 @@ all Perl documents contained in CPAN. This means the entire file in each
 case.
 
 PPI has succeeded in this goal far beyond the expectations of even the
-author. At time of writing there are only 28 non-Acme Perl modules in CPAN
+author. At time of writing there are only 28 non-Acme Perl files in CPAN
 that PPI is incapable of parsing. Most of these are so badly broken they
-do not compile as Perl code anyway.
+do not compile as Perl code either.
 
 So unless you are actively going out of your way to break PPI, you should
-expect that it will handle your code just fine.
-
-=head2 Internationalisation
-
-PPI provides partial support for internationalisation and localisation.
-
-Specifically, it allows the use of characters from the Latin-1 character
-set to be used in quotes, comments, and POD. Primarily, this covers
-languages from Europe and South America.
-
-PPI does B<not> currently provide support for Unicode.
-If you need Unicode support and would like to help,
-contact the author. (contact details below)
-
-=head2 Round Trip Safe
-
-When PPI parses a file it builds B<everything> into the model, including
-whitespace. This is needed in order to make the Document fully "Round Trip"
-safe.
-
-The general concept behind a "Round Trip" parser is that it knows what it
-is parsing is somewhat uncertain, and so B<expects> to get things wrong
-from time to time. In the cases where it parses code wrongly the tree
-will serialize back out to the same string of code that was read in,
-repairing the parser's mistake as it heads back out to the file.
-
-The end result is that if you parse in a file and serialize it back out
-without changing the tree, you are guaranteed to get the same file you
-started with. PPI does this correctly and reliably for 100% of all known
-cases.
-
-B<What goes in, will come out. Every time.>
-
-The one minor exception at this time is that if the newlines for your file
-are wrong (meaning not matching the platform newline format), PPI will
-localise them for you. (It isn't to be convenient, supporting
-arbitrary newlines would make some of the code more complicated)
-
-Better control of the newline type is on the wish list though, and
-anyone wanting to help out is encouraged to contact the author.
+expect that it will handle your code.
 
 =head1 IMPLEMENTATION
 
 =head2 General Layout
 
 PPI is built upon two primary "parsing" components, L<PPI::Tokenizer>
-and L<PPI::Lexer>, and a large tree of about 70 classes which implement
+and L<PPI::Lexer>, and a large tree of about 50 classes which implement
 the various the I<Perl Document Object Model> (PDOM).
 
 The PDOM is conceptually similar in style and intent to the regular DOM or
-other code Abstract Syntax Trees (ASTs), but contains some differences
-to handle perl-specific cases, and to assist in treating the code as a
-document. Please note that it is B<not> an implementation of the official
-Document Object Model specification, only somewhat similar to it.
+other code ASTs, but contains many differences to handle perl-specific cases,
+and to assist in treating the code as a document.
 
 On top of the Tokenizer, Lexer and the classes of the PDOM, sit a number
 of classes intended to make life a little easier when dealing with PDOM
@@ -324,34 +280,32 @@ codebase. Speaking of which...
 
 The Tokenizer takes source code and converts it into a series of tokens. It
 does this using a slow but thorough character by character manual process,
-rather than using a pattern system or complex regexes.
+rather than using a pattern system or complex regexs.
 
 Or at least it does so conceptually. If you were to actually trace the code
-you would find it's not truly character by character due to a number of
-regexps and optimisations throughout the code. This lets the Tokenizer
-"skip ahead" when it can find shortcuts, so it tends to jump around a line
+you would find it's not truly character by character due to a number if
+support regexps scattered throughout the code. This lets the Tokenizer
+skip ahead" when it can find shortcuts, so it tends to jump around a line
 a bit wildly at times.
 
-In practice, the number of times the Tokenizer will B<actually> move the
+Practically, the number of times the Tokenizer will B<actually> move the
 character cursor itself is only about 5% - 10% higher than the number of
-tokens contained in the file. This makes it about as optimal as it can be
-made without implementing it in something other than Perl.
+tokens contained in the file.
 
-In 2001 when PPI was started, this structure made PPI quite slow, and not
+In 2001 when PPI was started, this structure made PPI quote slow, and not
 really suitable for interactive tasks. This situation has improved greatly
 with multi-gigahertz processors, but can still be painful when working with
 very large files.
 
-The target parsing rate for PPI is about 5000 lines per gigacycle. It is
-currently believed to be at about 1500, and the main avenue for making it to
+The target speed rate for PPI is about 5000 lines per gigacycle. It is
+currently believed to be at about 1500, and main avenue for making it to
 the target speed has now become L<PPI::XS>, a drop-in XS accelerator for
 PPI.
 
 Since L<PPI::XS> has only just gotten off the ground and is currently only
 at proof-of-concept stage, this may take a little while. Anyone interested
 in helping out with L<PPI::XS> is B<highly> encouraged to contact the
-author. In fact, the design of L<PPI::XS> means it's possible to port
-one function at a time safely and reliably. So every little bit will help.
+author.
 
 =head2 The Lexer
 
@@ -365,7 +319,30 @@ produces L<PPI::Document> objects. However you should probably never be
 working with the Lexer directly. You should just be able to create
 L<PPI::Document> objects and work with them directly.
 
-=head2 The Perl Document Object Model
+=head2 Round Trip Safe
+
+When PPI parser a file it builds B<everything> into the model, including
+whitespace. This is needed in order to make the Document fully "Round Trip"
+safe.
+
+The general concept behind a "Round Trip" parser is that it knows what it
+is parsing is somewhat uncertain, and so B<expects> to get things wrong
+from time to time. In the cases where it parsers code wrongly the tree
+will serialize back out to the same string of code that was read in,
+repairing the parser's mistake is it heads back out to the file.
+
+The end result is that if you parse in a file and serialize it back out
+without changing the tree, you are guarenteed to get the same file you
+started with. PPI does this correctly and reliably for 100% of all known
+cases.
+
+B<What goes in, will come out. Every time.>
+
+The one minor exception at this time is that if the newlines for your file
+are wrong, PPI may perform a localisation of them for you. Better control
+of the newline type is a road map item for version 1.100.
+
+=head1 THE PERL DOCUMENT OBJECT MODEL
 
 The PDOM is a structured collection of data classes that together provide
 a correct and scalable model for documents that follow the standard Perl
@@ -373,7 +350,7 @@ syntax.
 
 =head2 The PDOM Class Tree
 
-The following lists all of the 72 current PDOM classes, listing with indentation
+The following lists all of the 62 current PDOM classes, listing with indentation
 based on inheritance.
 
    PPI::Element
@@ -381,14 +358,12 @@ based on inheritance.
          PPI::Document
             PPI::Document::Fragment
          PPI::Statement
+            PPI::Statement::Scheduled
             PPI::Statement::Package
             PPI::Statement::Include
             PPI::Statement::Sub
-               PPI::Statement::Scheduled
             PPI::Statement::Compound
             PPI::Statement::Break
-            PPI::Statement::Given
-            PPI::Statement::When
             PPI::Statement::Data
             PPI::Statement::End
             PPI::Statement::Expression
@@ -402,21 +377,13 @@ based on inheritance.
             PPI::Structure::Constructor
             PPI::Structure::Condition
             PPI::Structure::List
-            PPI::Structure::For
-            PPI::Structure::Given
-            PPI::Structure::When
+            PPI::Structure::ForLoop
             PPI::Structure::Unknown
       PPI::Token
          PPI::Token::Whitespace
          PPI::Token::Comment
          PPI::Token::Pod
          PPI::Token::Number
-            PPI::Token::Number::Binary
-            PPI::Token::Number::Octal
-            PPI::Token::Number::Hex
-            PPI::Token::Number::Float
-               PPI::Token::Number::Exp
-            PPI::Token::Number::Version
          PPI::Token::Word
          PPI::Token::DashedWord
          PPI::Token::Symbol
@@ -465,54 +432,46 @@ At the top of all complete PDOM trees is a L<PPI::Document> object. It
 represents a complete file of Perl source code as you might find it on
 disk.
 
-There are some specialised types of document, such as L<PPI::Document::File>
-and L<PPI::Document::Normalized> but for the purposes of the PDOM they are
-all just considered to be the same thing.
-
 Each Document will contain a number of B<Statements>, B<Structures> and
 B<Tokens>.
 
 A L<PPI::Statement> is any series of Tokens and Structures that are treated
 as a single contiguous statement by perl itself. You should note that a
 Statement is as close as PPI can get to "parsing" the code in the sense that
-perl-itself parses Perl code when it is building the op-tree.
+perl-itself parses Perl code when it is building the op-tree. Because of the
+assumed isolation, PPI cannot accurately determine precedence of operators
+or which tokens are implicit arguments to a sub call.
 
-Because of the isolation and Perl's syntax, it is provably impossible for
-PPI to accurately determine precedence of operators or which tokens are
-implicit arguments to a sub call.
+So rather than lead you on with a bad guess, PPI does not attempt to
+determine precedence or sub paramaters at all.
 
-So rather than lead you on with a bad guess that has a strong chance of
-being wrong, PPI does not attempt to determine precedence or sub parameters
-at all.
+At a fundamental level, it only knows that this series of elements represents
+a single Statement as perl sees it, and does so with reasonable certainty.
 
-At a fundamental level, it only knows that this series of elements
-represents a single Statement as perl sees it, but it can do so with
-enough certainty that it can be trusted.
-
-However, for specific Statement types the PDOM is able to derive additional
-useful information about their meaning. For the best, most useful, and most
-heavily used example, see L<PPI::Statement::Include>.
+However for specific Statement types the PDOM is able to derive additional
+useful information about their meaning. For the best and most heavily used
+example, see L<PPI::Statement::Include>.
 
 A L<PPI::Structure> is any series of tokens contained within matching braces.
 This includes code blocks, conditions, function argument braces, anonymous
-array and hash constructors, lists, scoping braces and all other syntactic
-structures represented by a matching pair of braces, including (although it
-may not seem obvious at first) C<E<lt>READLINEE<gt>> braces.
+array constructors, lists, scoping braces and all other syntactic structures
+represented by a matching pair of braces, including C<E<lt>READLINEE<gt>>
+braces.
 
 Each Structure contains none, one, or many Tokens and Structures (the rules
 for which vary for the different Structure subclasses)
 
-Under the PDOM structure rules, a Statement can B<never> directly contain
-another child Statement, a Structure can B<never> directly contain another
-child Structure, and a Document can B<never> contain another Document
-anywhere in the tree.
+In the PDOM structure rules, a Statement can B<never> directly contain another
+child Statement, a Structure can B<never> directly contain another child
+Structure, and a Document can B<never> contain another Document anywhere in
+the tree.
 
 Aside from these three rules, the PDOM tree is extremely flexible.
 
 =head2 The PDOM at Work
 
 To demonstrate the PDOM in use lets start with an example showing how the
-tree might look for the following chunk of simple Perl code.
+PDOM tree might look for the following chunk of simple Perl code.
 
   #!/usr/bin/perl
 
@@ -520,14 +479,13 @@ tree might look for the following chunk of simple Perl code.
 
   exit();
 
-Translated into a PDOM tree it would have the following structure (as shown
-via the included L<PPI::Dumper>).
+Translated into a PDOM tree it would have the following structure.
 
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
     PPI::Token::Whitespace             '\n'
     PPI::Statement
-      PPI::Token::Word                 'print'
+      PPI::Token::Bareword             'print'
       PPI::Structure::List             ( ... )
         PPI::Token::Whitespace         ' '
         PPI::Statement::Expression
@@ -537,14 +495,14 @@ via the included L<PPI::Dumper>).
     PPI::Token::Whitespace             '\n'
     PPI::Token::Whitespace             '\n'
     PPI::Statement
-      PPI::Token::Word                 'exit'
+      PPI::Token::Bareword             'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
     PPI::Token::Whitespace             '\n'
 
-Please note that in this example, strings are only listed for the
+Please note that in this this example, strings are only listed for the
 B<actual> L<PPI::Token> that contains that string. Structures are listed
-with the type of brace characters they represent noted.
+with the type of brace characters it represents noted.
 
 The L<PPI::Dumper> module can be used to generate similar trees yourself.
 
@@ -554,13 +512,13 @@ whitespace. Here it is again, sans the distracting whitespace tokens.
   PPI::Document
     PPI::Token::Comment                '#!/usr/bin/perl\n'
     PPI::Statement
-      PPI::Token::Word                 'print'
+      PPI::Token::Bareword             'print'
       PPI::Structure::List             ( ... )
         PPI::Statement::Expression
           PPI::Token::Quote::Double    '"Hello World!"'
       PPI::Token::Structure            ';'
     PPI::Statement
-      PPI::Token::Word                 'exit'
+      PPI::Token::Bareword             'exit'
       PPI::Structure::List             ( ... )
       PPI::Token::Structure            ';'
 
@@ -587,19 +545,16 @@ The Document object, the root of the PDOM.
 =item L<PPI::Document::Fragment>
 
 A cohesive fragment of a larger Document. Although not of any real current
-use, it is needed for use in certain internal tree manipulation
-algorithms.
+use, it is planned for use in certain internal tree manipulation
+algortihms.
 
 For example, doing things like cut/copy/paste etc. Very similar to a
 L<PPI::Document>, but has some additional methods and does not represent
 a lexical scope boundary.
 
-A document fragment is also non-serializable, and so cannot be written out
-to a file.
-
 =item L<PPI::Dumper>
 
-A simple class for dumping readable debugging versions of PDOM structures,
+A simple class for dumping readable debugging version of PDOM structures,
 such as in the demonstration above.
 
 =item L<PPI::Element>
@@ -626,7 +581,7 @@ The base class for all Perl statements. Generic "evaluate for side-effects"
 statements are of this actual type. Other more interesting statement types
 belong to one of its children.
 
-See its own documentation for a longer description and list of all of the
+See it's own documentation for a longer description and list of all of the
 different statement types and sub-classes.
 
 =item L<PPI::Structure>
@@ -647,7 +602,7 @@ some cases).
 
 The L<PPI::Token::Quote> and L<PPI::Token::QuoteLike> classes provide
 abstract base classes for the many and varied types of quote and
-quote-like things in Perl. However, much of the actual quote logic is
+quote-like things in Perl. However, much of the actual quote login is
 implemented in a separate quote engine, based at
 L<PPI::Token::_QuoteEngine>.
 
@@ -664,7 +619,7 @@ treads carefully when working with it.
 
 Most of the complication is the result of optimizations which have tripled
 the tokenization speed, at the expense of maintainability. We cope with the
-spaghetti by heavily commenting everything.
+spagetti by heavily commenting everything.
 
 =item L<PPI::Transform>
 
@@ -690,87 +645,75 @@ apply.
 
 =head1 EXTENDING
 
-The PPI namespace itself is reserved for use by PPI itself.
+The PPI namespace itself is reserved for the sole use of the modules under
+the umbrella of the C<Parse::Perl> SourceForge project.
+
+L<http://sf.net/parseperl>
+
 You are recommended to use the PPIx:: namespace for PPI-specific
 modifications or prototypes thereof, or Perl:: for modules which provide
 a general Perl language-related functions.
 
-If what you wish to implement looks like it fits into the PPIx:: namespace,
-you should consider contacting the PPI maintainers on GitHub first, as what
-you want may already be in progress, or you may wish to consider contributing
-to PPI itself.
+If what you wish to implement looks like it fits into PPIx:: namespace,
+you should consider contacting the C<Parse::Perl> mailing list (detailed on
+the SourceForge site) first, as what you want may already be in progress,
+or you may wish to consider joining the team and doing it within the
+C<Parse::Perl> project itself.
 
 =head1 TO DO
 
-- Many more analysis and utility methods for PDOM classes
+- Many more analysis and utility methods for PDOM classes (post 1.000)
 
-- Creation of a PPI::Tutorial document
+- Creation of a PPI::Tutorial document (post 1.000)
 
-- Add many more key functions to PPI::XS
+- We can _always_ write more and better unit tests
 
-- We can B<always> write more and better unit tests
+- Add better support for tabs (1.100)
 
-- Complete the full implementation of -E<gt>literal (1.200)
+- Add better handling of non-local newlines (due 1.100)
 
-- Full understanding of scoping (due 1.300)
+- Full understanding of scoping (due 1.100)
+
+- Add many more key functions to PPI::XS (post 1.000)
 
 =head1 SUPPORT
 
-The most recent version of PPI is available at the following address.
+Bugs should be always be reported vi the following URI
 
-L<https://metacpan.org/pod/PPI>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PPI>
 
-PPI source is maintained in a GitHub repository at the following address.
+When reporting bugs, you are B<highly> recommended to include test
+cases if at all possible, as the odds are by the time you are
+submitting a bug you understand what should actually happen better
+than the authors.
 
-L<https://github.com/Perl-Critic/PPI>
+Test fragments are fine, or in larger cases simply copy/paste one of
+the other small test scripts and replace the contents with your own
+tests.
 
-Contributions via GitHub pull request are welcome.
+For other issues or questions, contact the C<Parse::Perl> project mailing
+list.
 
-Bug fixes in the form of pull requests or bug reports with
-new (failing) unit tests have the best chance of being addressed
-by busy maintainers, and are B<strongly> encouraged.
-
-If you cannot provide a test or fix, or don't have time to do so,
-then regular bug reports are still accepted and appreciated via the
-GitHub bug tracker.
-
-L<https://github.com/Perl-Critic/PPI/issues>
-
-The C<ppidump> utility that is part of the L<Perl::Critic> distribution
-is a useful tool for demonstrating how PPI is parsing (or misparsing)
-small code snippets, and for providing information for bug reports.
-
-For other issues, questions, or commercial or media-related enquiries,
-contact the author.
+For commercial or media issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy <cpan@ali.as>, L<http://ali.as/>
 
 =head1 ACKNOWLEDGMENTS
 
-A huge thank you to Phase N Australia
-(L<https://web.archive.org/web/20240304122957/http://www.phase-n.com/>) for
-permitting the original open sourcing and release of this distribution from
-what was originally several thousand hours of commercial work.
+A huge thank you to Phase N Australia (L<http://phase-n.com/>) for
+permitting the original open sourcing and release of this distribution
+from what was originally several thousand hours of commercial work.
 
 Another big thank you to The Perl Foundation
 (L<http://www.perlfoundation.org/>) for funding for the final big
 refactoring and completion run.
 
-Also, to the various co-maintainers that have contributed both large and
-small with tests and patches and especially to those rare few who have
-deep-dived into the guts to (gasp) add a feature.
-
-  - Dan Brook       : PPIx::XPath, Acme::PerlML
-  - Audrey Tang     : "Line Noise" Testing
-  - Arjen Laarhoven : Three-element ->location support
-  - Elliot Shank    : Perl 5.10 support, five-element ->location
-
-And finally, thanks to those brave ( and foolish :) ) souls willing to dive
-in and use, test drive and provide feedback on PPI before version 1.000,
-in some cases before it made it to beta quality, and still did extremely
-distasteful things (like eating 50 meg of RAM a second).
+Most of all, thanks to those brave soles willing to dive in and use,
+test drive and provide feedback on PPI, in a few cases before it was
+tamed and ready, and still did extremely distasteful things to you like
+eating 50 meg of RAM a second.
 
 I owe you all a beer. Corner me somewhere and collect at your convenience.
 If I missed someone who wasn't in my email history, thank you too :)
@@ -783,7 +726,7 @@ If I missed someone who wasn't in my email history, thank you too :)
   - Robert Rotherberg
   - CPAN Author "PODMASTER"
   - Richard Soderberg
-  - Nadim ibn Hamouda el Khemir
+  - "Nadim"
   - Graciliano M. P.
   - Leon Brocard
   - Jody Belka
@@ -801,18 +744,14 @@ If I missed someone who wasn't in my email history, thank you too :)
   - Johnny Lee
   - Johan Lindstrom
 
-And to single one person out, thanks go to Randal Schwartz who
-spent a great number of hours in IRC over a critical 6 month period
-explaining why Perl is impossibly unparsable and constantly shoving evil
-and ugly corner cases in my face. He remained a tireless devil's advocate,
-and without his support this project genuinely could never have been
-completed.
-
-So for my schooling in the Deep Magiks, you have my deepest gratitude Randal.
+And to single one person out, thank you to Randal Schwartz who (mostly)
+patiently spent a great number of hours in IRC over a critical 6 month
+period "aggresively explaining" why Perl is impossibly unparsable and
+shoving evil and ugly corner cases in my face.
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
