@@ -10,7 +10,7 @@ PPI::Document::Fragment - A fragment of a Perl Document
 
 In some situations you might want to work with a fragment of a larger
 document. C<PPI::Document::Fragment> is a class intended for this purpose.
-It is functionally almost identical to a normal L<PPI::Document>, except
+It is functionaly almost identical to a normal L<PPI::Document>, except
 that it is not possible to get line/column positions for the elements
 within it, and it does not represent a scope.
 
@@ -19,11 +19,13 @@ within it, and it does not represent a scope.
 =cut
 
 use strict;
-use PPI::Document ();
+use base 'PPI::Document';
+use UNIVERSAL 'isa';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = 'PPI::Document';
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -58,7 +60,7 @@ sub index_locations {
 
 # We are not a scope boundary
 ### XS -> PPI/XS.xs:_PPI_Document_Fragment__scope 0.903+
-sub scope() { '' }
+sub scope { '' }
 
 1;
 
@@ -71,15 +73,15 @@ obvious would be to implement arbitrary cut/copy/paste more easily.
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
