@@ -8,9 +8,9 @@ PPI::Document::Normalized - A normalized Perl Document
 
 =head1 DESCRIPTION
 
-A C<Normalized Document> object is the result of the normalization process
-contained in the L<PPI::Normal> class. See the documentation for
-L<PPI::Normal> for more information.
+A Normalized Document object is the result of the normalization process
+contained in the L<PPI::Normal> class. See its documentation for more
+information.
 
 The object contains a version stamp and function list for the version
 of L<PPI::Normal> used to create it, and a processed and delinked
@@ -20,11 +20,10 @@ Typically, the Document object will have been mangled by the normalization
 process in a way that would make it fatal to try to actually DO anything
 with it.
 
-Put simply, B<never> use the Document object after normalization.
-B<YOU HAVE BEEN WARNED!>
+Put simply, B<never> use the Document object. B<YOU HAVE BEEN WARNED!>
 
 The object is designed the way it is to provide a bias towards false
-negatives. A comparison between two ::Normalized object will only return
+negatives. A comparison between to ::Normalized object will only return
 true if they were produced by the same version of PPI::Normal, with the
 same set of normalization functions (in the same order).
 
@@ -38,18 +37,21 @@ a code security process, and false positives could be highly dangerous.
 
 =cut
 
+use strict;
+use UNIVERSAL 'isa';
+use overload 'bool' => sub () { 1 },
+             '=='   => 'equal';
+
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
+
 # For convenience (and since this isn't really a public class), import
 # the methods we will need from Scalar::Util.
-use strict;
-use Scalar::Util qw{refaddr reftype blessed};
-use Params::Util qw{_INSTANCE _ARRAY};
-use PPI::Util    ();
-
-our $VERSION = '1.28401'; # TRIAL
-
-use overload 'bool' => \&PPI::Util::TRUE;
-use overload '=='   => 'equal';
-
+use Scalar::Util 'refaddr',
+                 'reftype',
+                 'blessed';
 
 
 
@@ -74,9 +76,9 @@ sub new {
 	my %args  = @_;
 
 	# Check the required params
-	my $Document  = _INSTANCE($args{Document}, 'PPI::Document') or return undef;
-	my $version   = $args{version};
-	my $functions = _ARRAY($args{functions}) or return undef;
+	my $Document  = isa($args{Document}, 'PPI::Document') ? $args{Document} : return undef;
+	my $version   = $args{version} or return undef;
+	my $functions = ref $args{functions} eq 'ARRAY' ? $args{functions} : return undef;
 
 	# Create the object
 	my $self = bless {
@@ -144,15 +146,13 @@ or C<undef> if there is an error.
 
 sub equal {
 	my $self  = shift;
-	my $other = _INSTANCE(shift, 'PPI::Document::Normalized') or return undef;
+	my $other = isa(ref $_[0], 'PPI::Document::Normalized') ? shift : return undef;
 
 	# Prevent multiple concurrent runs
 	return undef if $self->{processing};
 
 	# Check the version and function list first
-	my $v1 = $self->version || "undef";
-	my $v2 = $other->version || "undef";
-	return '' if $v1 ne $v2;
+	return '' unless $self->version == $other->version;
 	$self->_equal_ARRAY( $self->functions, $other->functions ) or return '';
 
 	# Do the main comparison run
@@ -295,15 +295,15 @@ sub DESTROY {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2011 Adam Kennedy.
+Copyright (c) 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
