@@ -33,9 +33,12 @@ generate the dump content itself.
 =cut
 
 use strict;
-use Params::Util qw{_INSTANCE};
+use Params::Util '_INSTANCE';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -77,7 +80,7 @@ True/false value, on by default.
 =item content
 
 Should the dumper show the content of each element. True/false value,
-on by default.
+on by defauilt.
 
 =item whitespace
 
@@ -89,13 +92,7 @@ made much clearer. True/false value, on by default.
 
 Should the dumper show comment tokens. In situations where you have
 a lot of comments, the code can often be made clearer by ignoring
-comment tokens. True/false value, on by default.
-
-=item locations
-
-Should the dumper show the location of each token. The values shown are
-[ line, rowchar, column ]. See L<PPI::Element/"location"> for a description of
-what these values really are. True/false value, off by default.
+comment tokens. True/value value, on by default.
 
 =back
 
@@ -115,13 +112,11 @@ sub new {
 			content    => 1,  # Show the object contents
 			whitespace => 1,  # Show whitespace tokens
 			comments   => 1,  # Show comment tokens
-			locations  => 0,  # Show token locations
 			},
 		}, $class;
 
 	# Handle the options
-	my @options = map { lc $_ } @_; # strict hashpairs # https://github.com/Perl-Critic/PPI/issues/201
-	my %options = @options;
+	my %options = map { lc $_ } @_;
 	foreach ( keys %{$self->{display}} ) {
 		if ( exists $options{$_} ) {
 			if ( $_ eq 'indent' ) {
@@ -181,7 +176,7 @@ sub string {
 The C<list> method generates the dump and provides it as a raw
 list, without trailing newlines.
 
-Returns a list or the null list if there is an error while generating
+Returns a list or the null list if there is an error while generation
 the dump.
 
 =cut
@@ -234,20 +229,7 @@ sub _element_string {
 	if ( $self->{display}->{memaddr} ) {
 		$string .= $Element->refaddr . '  ';
 	}
-        
-        # Add the location if such exists
-	if ( $self->{display}->{locations} ) {
-		my $loc_string;
-		if ( $Element->isa('PPI::Token') ) {
-			my $location = $Element->location;
-			if ($location) {
-				$loc_string = sprintf("[ % 4d, % 3d, % 3d ] ", @$location);
-			}
-		}
-		# Output location or pad with 20 spaces
-		$string .= $loc_string || " " x 20;
-	}
-        
+
 	# Add the indent
 	if ( $self->{display}->{indent} ) {
 		$string .= $indent;
@@ -264,7 +246,6 @@ sub _element_string {
 			my $content = $Element->content;
 			$content =~ s/\n/\\n/g;
 			$content =~ s/\t/\\t/g;
-			$content =~ s/\f/\\f/g;
 			$string .= "  \t'$content'";
 		}
 
@@ -290,15 +271,15 @@ sub _element_string {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
