@@ -22,23 +22,26 @@ implementations.
 =cut
 
 use strict;
-use Clone 0.30      ();
-use Scalar::Util    qw{refaddr};
-use Params::Util    qw{_INSTANCE _ARRAY};
-use PPI::Util       ();
+use UNIVERSAL 'isa';
+use Scalar::Util 'refaddr';
+use Params::Util '_INSTANCE',
+                 '_ARRAY';
 use PPI::Node       ();
-use PPI::Singletons '%_PARENT', '%_POSITION_CACHE';
+use Clone           ();
+use List::MoreUtils ();
+use overload 'bool' => sub () { 1 },
+             '""'   => 'content',
+             '=='   => '__equals',
+             'eq'   => '__eq';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION $errstr %_PARENT};
+BEGIN {
+	$VERSION = '1.001';
+	$errstr  = '';
 
-our $errstr = "";
-
-use overload 'bool' => \&PPI::Util::TRUE;
-use overload '""'   => 'content';
-use overload '=='   => '__equals';
-use overload '!='   => '__nequals';
-use overload 'eq'   => '__eq';
-use overload 'ne'   => '__ne';
+	# Master Child -> Parent index
+	%_PARENT = ();
+}
 
 
 
@@ -54,7 +57,7 @@ use overload 'ne'   => '__ne';
 Because we treat whitespace and other non-code items as Tokens (in order to
 be able to "round trip" the L<PPI::Document> back to a file) the
 C<significant> method allows us to distinguish between tokens that form a
-part of the code, and tokens that aren't significant, such as whitespace,
+part of the code, and tokens that arn't significant, such as whitespace,
 POD, or the portion of a file after (and including) the C<__END__> token.
 
 Returns true if the Element is significant, or false it not.
@@ -62,7 +65,7 @@ Returns true if the Element is significant, or false it not.
 =cut
 
 ### XS -> PPI/XS.xs:_PPI_Element__significant 0.845+
-sub significant() { 1 }
+sub significant { 1 }
 
 =pod
 
@@ -70,7 +73,7 @@ sub significant() { 1 }
 
 The C<class> method is provided as a convenience, and really does nothing
 more than returning C<ref($self)>. However, some people have found that
-they appreciate the laziness of C<$Foo-E<gt>class eq 'whatever'>, so I
+they appreciate the lazyness of C<$Foo-E<gt>class eq 'whatever'>, so I
 have caved to popular demand and included it.
 
 Returns the class of the Element as a string
@@ -117,14 +120,14 @@ Returns the basic code as a string (excluding here-doc content).
 =cut
 
 ### XS -> PPI/XS.xs:_PPI_Element__content 0.900+
-sub content() { '' }
+sub content { '' }
 
 
 
 
 
 #####################################################################
-# Navigation Methods
+# Naigation Methods
 
 =pod
 
@@ -143,48 +146,10 @@ sub parent { $_PARENT{refaddr $_[0]} }
 
 =pod
 
-=head2 descendant_of $element
-
-Answers whether a C<PPI::Element> is contained within another one.
-
-C<PPI::Element>s are considered to be descendants of themselves.
-
-=cut
-
-sub descendant_of {
-	my $cursor = shift;
-	my $parent = shift or return undef;
-	while ( refaddr $cursor != refaddr $parent ) {
-		$cursor = $_PARENT{refaddr $cursor} or return '';
-	}
-	return 1;
-}
-
-=pod
-
-=head2 ancestor_of $element
-
-Answers whether a C<PPI::Element> is contains another one.
-
-C<PPI::Element>s are considered to be ancestors of themselves.
-
-=cut
-
-sub ancestor_of {
-	my $self   = shift;
-	my $cursor = shift or return undef;
-	while ( refaddr $cursor != refaddr $self ) {
-		$cursor = $_PARENT{refaddr $cursor} or return '';
-	}
-	return 1;
-}
-
-=pod
-
 =head2 statement
 
 For a C<PPI::Element> that is contained (at some depth) within a
-L<PPI::Statement>, the C<statement> method will return the first parent
+L<PPI::Statment>, the C<statement> method will return the first parent
 Statement object lexically 'above' the Element.
 
 Returns a L<PPI::Statement> object, which may be the same Element if the
@@ -228,8 +193,6 @@ sub top {
 
 =pod
 
-=head2 document
-
 For an Element that is contained within a L<PPI::Document> object,
 the C<document> method will return the top-level Document for the Element.
 
@@ -255,10 +218,12 @@ immediately after the current one, or false if there is no next sibling.
 
 sub next_sibling {
 	my $self     = shift;
+	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
-	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = $parent->__position($self);
+	my $position = List::MoreUtils::firstidx {
+		refaddr $_ == $key
+		} @$elements;
 	$elements->[$position + 1] || '';
 }
 
@@ -276,10 +241,12 @@ sibling.
 
 sub snext_sibling {
 	my $self     = shift;
+	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
-	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = $parent->__position($self);
+	my $position = List::MoreUtils::firstidx {
+		refaddr $_ == $key
+		} @$elements;
 	while ( defined(my $it = $elements->[++$position]) ) {
 		return $it if $it->significant;
 	}
@@ -299,10 +266,12 @@ C<PPI::Element> object.
 
 sub previous_sibling {
 	my $self     = shift;
+	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
-	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = $parent->__position($self);
+	my $position = List::MoreUtils::firstidx {
+		refaddr $_ == $key
+		} @$elements;
 	$position and $elements->[$position - 1] or '';
 }
 
@@ -320,10 +289,12 @@ sibling.
 
 sub sprevious_sibling {
 	my $self     = shift;
+	my $parent   = $_PARENT{refaddr $self} or return '';
 	my $key      = refaddr $self;
-	my $parent   = $_PARENT{$key} or return '';
 	my $elements = $parent->{children};
-	my $position = $parent->__position($self);
+	my $position = List::MoreUtils::firstidx {
+		refaddr $_ == $key
+		} @$elements;
 	while ( $position-- and defined(my $it = $elements->[$position]) ) {
 		return $it if $it->significant;
 	}
@@ -344,7 +315,7 @@ the same object.
 
 Returns a L<PPI::Token> object, or dies on error (which should be extremely
 rare and only occur if an illegal empty L<PPI::Statement> exists below the
-current Element somewhere.)
+current Element somewhere.
 
 =cut
 
@@ -352,7 +323,7 @@ sub first_token {
 	my $cursor = shift;
 	while ( $cursor->isa('PPI::Node') ) {
 		$cursor = $cursor->first_element
-		or die "Found empty PPI::Node while getting first token";
+			or die "Found empty PPI::Node while getting first token";
 	}
 	$cursor;
 }
@@ -372,7 +343,7 @@ the itself.
 
 Returns a L<PPI::Token> object, or dies on error (which should be extremely
 rare and only occur if an illegal empty L<PPI::Statement> exists below the
-current Element somewhere.)
+current Element somewhere.
 
 =cut
 
@@ -380,7 +351,7 @@ sub last_token {
 	my $cursor = shift;
 	while ( $cursor->isa('PPI::Node') ) {
 		$cursor = $cursor->last_element
-		or die "Found empty PPI::Node while getting first token";
+			or die "Found empty PPI::Node while getting first token";
 	}
 	$cursor;
 }
@@ -400,7 +371,7 @@ because it can be useful to find the next token that is after, say, a
 L<PPI::Statement>, although obviously it would be useless to want the
 next token after a L<PPI::Document>.
 
-Returns a L<PPI::Token> object, or false if there are no more tokens after
+Returns a L<PPI::Token> object, or false if there are no more token after
 the Element.
 
 =cut
@@ -408,18 +379,27 @@ the Element.
 sub next_token {
 	my $cursor = shift;
 
-	# Find the next element, going upwards as needed
-	while ( 1 ) {
-		my $element = $cursor->next_sibling;
-		if ( $element ) {
-			return $element if $element->isa('PPI::Token');
-			return $element->first_token;
-		}
-		$cursor = $cursor->parent or return '';
-		if ( $cursor->isa('PPI::Structure') and $cursor->finish ) {
-			return $cursor->finish;
-		}
+	# Start with the next Element. Go up via our parents if needed.
+	my $Element;
+	while ( defined($Element = $cursor->next_sibling) ) {
+		$cursor = $_PARENT{refaddr $cursor} or return '';
 	}
+
+	# If the Element is not itself a Token, work our way downwards
+	# through the first child of each level till we find one
+	### Note: There's a few potential problems with this part of the
+	###       algorithm, but it will be safe as long as PPI::Token
+	###       is the ONLY class to inherit from PPI::Element other
+	###       than PPI::Node. This is because first_element is really
+	###       a PPI::Node method, NOT a PPI::Element method, so we are
+	###       using it in a slightly unsafe context. Again though, in
+	###       the class structure as of the time this method was written,
+	###       this is safe.
+	while ( ! $Element->isa('PPI::Token') ) {
+		defined($Element = $Element->first_element) or return '';
+	}
+
+	$Element;
 }
 
 =pod
@@ -444,47 +424,26 @@ the C<Element>.
 sub previous_token {
 	my $cursor = shift;
 
-	# Find the previous element, going upwards as needed
-	while ( 1 ) {
-		my $element = $cursor->previous_sibling;
-		if ( $element ) {
-			return $element if $element->isa('PPI::Token');
-			return $element->last_token;
-		}
-		$cursor = $cursor->parent or return '';
-		if ( $cursor->isa('PPI::Structure') and $cursor->start ) {
-			return $cursor->start;
-		}
-	}
-}
-
-=head2 presumed_features
-
-Returns a hash that indicates which features appear to be active for the given
-element.
-
-=cut
-
-sub presumed_features {
-	my ($self) = @_;
-
-	my @feature_mods;
-	my $walker = $self;
-	while ($walker) {
-		my $sib_walk = $walker;
-		while ($sib_walk) {
-			push @feature_mods, $sib_walk if $sib_walk->can("feature_mods");
-			$sib_walk = $sib_walk->sprevious_sibling;
-		}
-		$walker = $walker->parent;
+	# Start with the next Element.
+	# Go up via our parents if needed.
+	my $Element;
+	while ( defined($Element = $cursor->previous_sibling) ) {
+		$cursor = $_PARENT{refaddr $cursor} or return '';
 	}
 
-	my %feature_mods = map %{$_}, reverse grep defined, map $_->feature_mods,
-	  @feature_mods;
+	# If the Element is not itself a Token, work our way downwards
+	# through the last child of each level till we find one
+	while ( ! $Element->isa('PPI::Token') ) {
+		defined($Element = $Element->last_element) or return '';
+	}
 
-	return \%feature_mods;
+	$Element;
 }
 
+
+
+
+
 #####################################################################
 # Manipulation
 
@@ -520,13 +479,14 @@ In future, this method may be enhanced to allow the insertion of multiple
 Elements, inline-parsed code strings or L<PPI::Document::Fragment> objects.
 
 Returns true if the Element was inserted, false if it can not be inserted,
-or C<undef> if you do not provide a C<PPI::Element> object as a parameter.
+or C<undef> if you do not provide a L<PPI::Element> object as a parameter.
 
 =cut
 
+# The internal version, which trusts the data we are given
 sub __insert_before {
 	my $self = shift;
-	$self->parent->__insert_before_child( $self, @_ );
+	
 }
 
 =pod
@@ -545,13 +505,14 @@ In future, this method may be enhanced to allow the insertion of multiple
 Elements, inline-parsed code strings or L<PPI::Document::Fragment> objects.
 
 Returns true if the Element was inserted, false if it can not be inserted,
-or C<undef> if you do not provide a C<PPI::Element> object as a parameter.
+or C<undef> if you do not provide a L<PPI::Element> object as a parameter.
 
 =cut
 
+# The internal version, which trusts the data we are given
 sub __insert_after {
 	my $self = shift;
-	$self->parent->__insert_after_child( $self, @_ );
+	
 }
 
 =pod
@@ -576,7 +537,7 @@ sub remove {
 
 =head2 delete
 
-For a given C<PPI::Element>, the C<delete> method will remove it from its
+For a given C<PPI::Element>, the C<remove> method will remove it from its
 parent, immediately deleting the C<Element> and all of its children (if it
 has any).
 
@@ -603,14 +564,12 @@ To prevent accidental damage to code, in this initial implementation the
 replacement element B<must> be of the same class (or a subclass) as the
 one being replaced.
 
-If successful, returns the replace element.  Otherwise, returns C<undef>.
-
 =cut
 
 sub replace {
 	my $self    = ref $_[0] ? shift : return undef;
-	my $replace = _INSTANCE(shift, ref $self) or return undef;
-	return $self->parent->replace_child( $self, $replace );
+	my $Element = isa(ref $_[0], ref $self) ? shift : return undef;
+	die "The ->replace method has not yet been implemented";
 }
 
 =pod
@@ -622,145 +581,19 @@ indexed the Element locations using C<PPI::Document::index_locations>, the
 C<location> method will return the location of the first character of the
 Element within the Document.
 
-Returns the location as a reference to a five-element array in the form C<[
-$line, $rowchar, $col, $logical_line, $logical_file_name ]>. The values are in
-a human format, with the first character of the file located at C<[ 1, 1, 1, ?,
-'something' ]>.
-
-The second and third numbers are similar, except that the second is the
-literal horizontal character, and the third is the visual column, taking
-into account tabbing (see L<PPI::Document/"tab_width [ $width ]">).
-
-The fourth number is the line number, taking into account any C<#line>
-directives.  The fifth element is the name of the file that the element was
-found in, if available, taking into account any C<#line> directives.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
+Returns the location as a reference to a two-element array in the form
+C<[ $line, $col ]>. The values are in a human format, with the first
+character of the file located at C<[ 1, 1 ]>. Returns C<undef> on error,
+or if the L<PPI::Document> object has not been indexed.
 
 =cut
 
 sub location {
 	my $self = shift;
-
-	$self->_ensure_location_present or return undef;
-
-	# Return a copy, not the original
-	return [ @{$self->{_location}} ];
-}
-
-=pod
-
-=head2 line_number
-
-If the Element exists within a L<PPI::Document> that has indexed the Element
-locations using C<PPI::Document::index_locations>, the C<line_number> method
-will return the line number of the first character of the Element within the
-Document.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
-
-=cut
-
-sub line_number {
-	my $self = shift;
-
-	my $location = $self->location() or return undef;
-	return $location->[0];
-}
-
-=pod
-
-=head2 column_number
-
-If the Element exists within a L<PPI::Document> that has indexed the Element
-locations using C<PPI::Document::index_locations>, the C<column_number> method
-will return the column number of the first character of the Element within the
-Document.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
-
-=cut
-
-sub column_number {
-	my $self = shift;
-
-	my $location = $self->location() or return undef;
-	return $location->[1];
-}
-
-=pod
-
-=head2 visual_column_number
-
-If the Element exists within a L<PPI::Document> that has indexed the Element
-locations using C<PPI::Document::index_locations>, the C<visual_column_number>
-method will return the visual column number of the first character of the
-Element within the Document, according to the value of
-L<PPI::Document/"tab_width [ $width ]">.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
-
-=cut
-
-sub visual_column_number {
-	my $self = shift;
-
-	my $location = $self->location() or return undef;
-	return $location->[2];
-}
-
-=pod
-
-=head2 logical_line_number
-
-If the Element exists within a L<PPI::Document> that has indexed the Element
-locations using C<PPI::Document::index_locations>, the C<logical_line_number>
-method will return the line number of the first character of the Element within
-the Document, taking into account any C<#line> directives.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
-
-=cut
-
-sub logical_line_number {
-	my $self = shift;
-
-	return $self->location()->[3];
-}
-
-=pod
-
-=head2 logical_filename
-
-If the Element exists within a L<PPI::Document> that has indexed the Element
-locations using C<PPI::Document::index_locations>, the C<logical_filename>
-method will return the logical file name containing the first character of the
-Element within the Document, taking into account any C<#line> directives.
-
-Returns C<undef> on error, or if the L<PPI::Document> object has not been
-indexed.
-
-=cut
-
-sub logical_filename {
-	my $self = shift;
-
-	my $location = $self->location() or return undef;
-	return $location->[4];
-}
-
-sub _ensure_location_present {
-	my $self = shift;
-
 	unless ( exists $self->{_location} ) {
 		# Are we inside a normal document?
 		my $Document = $self->document or return undef;
-		if ( $Document->isa('PPI::Document::Fragment') ) {
+		unless ( $Document->isa('PPI::Document::Fragment') ) {
 			# Because they can't be serialized, document fragments
 			# do not support the concept of location.
 			return undef;
@@ -776,7 +609,8 @@ sub _ensure_location_present {
 		}
 	}
 
-	return 1;
+	# Return a copy, not the original
+	return [ @{$self->{_location}} ];
 }
 
 # Although flush_locations is only publically a Document-level method,
@@ -794,13 +628,13 @@ sub _flush_locations {
 
 	# Optionally allow starting from an arbitrary element (or rather,
 	# the first Token equal-to-or-within an arbitrary element)
-	if ( _INSTANCE($_[0], 'PPI::Element') ) {
+	if ( isa($_[0], 'PPI::Element') ) {
 		my $start = shift->first_token;
 		while ( my $Token = shift @Tokens ) {
 			return 1 unless $Token->{_location};
 			next unless refaddr($Token) == refaddr($start);
 
-			# Found the start. Flush its location
+			# Found the start. Flush it's location
 			delete $$Token->{_location};
 			last;
 		}
@@ -858,20 +692,16 @@ sub _clear {
 # ->delete means our reference count has probably fallen to zero.
 # Therefore we don't need to remove ourselves from our parent,
 # just the index ( just in case ).
-sub DESTROY {
-  delete $_PARENT{refaddr $_[0]};
-  delete $_POSITION_CACHE{refaddr $_[0]};
-}
+### XS -> PPI/XS.xs:_PPI_Element__DESTROY 0.900+
+sub DESTROY { delete $_PARENT{refaddr $_[0]} }
 
 # Operator overloads
-sub __equals  { ref $_[1] and refaddr($_[0]) == refaddr($_[1]) }
-sub __nequals { !__equals(@_) }
+sub __equals { ref $_[1] and refaddr($_[0]) == refaddr($_[1]) }
 sub __eq {
 	my $self  = _INSTANCE($_[0], 'PPI::Element') ? $_[0]->content : $_[0];
 	my $other = _INSTANCE($_[1], 'PPI::Element') ? $_[1]->content : $_[1];
 	$self eq $other;
 }
-sub __ne { !__eq(@_) }
 
 1;
 
@@ -888,15 +718,15 @@ as error handlers.
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
