@@ -72,9 +72,12 @@ caught by the Find object and returned as an error.
 =cut
 
 use strict;
-use Params::Util qw{_INSTANCE};
+use UNIVERSAL 'isa';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -101,7 +104,7 @@ sub new {
 	# Create the object
 	my $self = bless {
 		wanted => $wanted,
-	}, $class;
+		}, $class;
 
 	$self;
 }
@@ -114,7 +117,7 @@ The C<clone> method creates another instance of the same Find object.
 
 The cloning is done safely, so if your existing Find object is in the
 middle of an iteration, the cloned Find object will not also be in the
-iteration and can be safely used independently.
+iteration and can be safely used independantly.
 
 Returns a duplicate PPI::Find object.
 
@@ -128,7 +131,7 @@ sub clone {
 	# Create the object
 	my $clone = bless {
 		wanted => $self->{wanted},
-	}, $class;
+		}, $class;
 
 	$clone;
 }
@@ -157,7 +160,7 @@ returned the null list, which may also mean simply that no Elements
 were found that matched the condition.
 
 Because of this need to explicitly check for errors, an alternative
-return value mechanism is provide. If you pass the C<< array_ref => 1 >>
+return value mechanism is provide. If you pass the C<array_ref => 1>
 parameter to the method, it will return the list of matched Elements
 as a reference to an ARRAY. The method will return false if no elements
 were matched, or C<undef> on error.
@@ -178,7 +181,7 @@ sub in {
 	}
 
 	# Get the root element for the search
-	unless ( _INSTANCE($Element, 'PPI::Element') ) {
+	unless ( isa($Element, 'PPI::Element') ) {
 		return $self->_error('->in was not passed a PPI::Element object', %params);
 	}
 
@@ -187,7 +190,10 @@ sub in {
 	$self->{matches} = [];
 
 	# Execute the search
-	if ( !eval { $self->_execute; 1 } ) {
+	eval {
+		$self->_execute;
+	};
+	if ( $@ ) {
 		my $errstr = $@;
 		$errstr =~ s/\s+at\s+line\s+.+$//;
 		return $self->_error("Error while searching: $errstr", %params);
@@ -212,7 +218,7 @@ sub in {
 
 =head2 start $Element
 
-The C<start> method lets the Find object act as an iterator. The method
+The C<start> method lets the Find object act as an interator. The method
 is passed the parent PPI::Element object as for the C<in> method, but does
 not accept any parameters.
 
@@ -234,7 +240,7 @@ sub start {
 	}
 
 	# Get the root element for the search
-	unless ( _INSTANCE($Element, 'PPI::Element') ) {
+	unless ( isa($Element, 'PPI::Element') ) {
 		return $self->_error('->in was not passed a PPI::Element object');
 	}
 
@@ -243,7 +249,10 @@ sub start {
 	$self->{matches} = [];
 
 	# Execute the search
-	if ( !eval { $self->_execute; 1 } ) {
+	eval {
+		$self->_execute;
+	};
+	if ( $@ ) {
 		my $errstr = $@;
 		$errstr =~ s/\s+at\s+line\s+.+$//;
 		$self->_error("Error while searching: $errstr");
@@ -280,12 +289,12 @@ sub match {
 
 =head2 finish
 
-The C<finish> method provides a mechanism to end iteration if you wish to
+The C<finish> method provides a mechanism to end interation if you wish to
 stop the iteration prematurely. It resets the Find object and allows it to
 be safely reused.
 
 A Find object will be automatically finished when C<match> returns false.
-This means you should only need to call C<finish> when you stop
+This means you should only need to call C<finnish> when you stop
 iterating early.
 
 You may safely call this method even when not iterating and it will return
@@ -316,7 +325,7 @@ sub _execute {
 	my @queue  = ( $self->{in} );
 
 	# Pull entries off the queue and hand them off to the wanted function
-	while ( my $Element = shift @queue ) {
+	while ( my $Element = shift @{$self->{queue}} ) {
 		my $rv = &$wanted( $Element, $self->{in} );
 
 		# Add to the matches if returns true
@@ -337,6 +346,8 @@ sub _execute {
 		}
 	}
 
+	# Save the queue and return
+	$self->{queue} = \@queue;
 	1;
 }
 
@@ -372,15 +383,15 @@ sub _error {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
