@@ -49,15 +49,17 @@ L<PPI::Element> objects also apply to C<PPI::Node> objects.
 =cut
 
 use strict;
-use Carp            ();
-use Scalar::Util    qw{refaddr};
-use Params::Util    qw{_INSTANCE _CLASS _CODELIKE _NUMBER};
-use PPI::Element    ();
-use PPI::Singletons '%_PARENT', '%_POSITION_CACHE';
+use base 'PPI::Element';
+use Scalar::Util 'refaddr';
+use Params::Util '_INSTANCE';
+use List::MoreUtils ();
+use Carp ();
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Element";
+use vars qw{$VERSION *_PARENT};
+BEGIN {
+	$VERSION = '1.001';
+	*_PARENT = *PPI::Element::_PARENT;
+}
 
 
 
@@ -88,7 +90,7 @@ boundary, or false if it does not.
 =cut
 
 ### XS -> PPI/XS.xs:_PPI_Node__scope 0.903+
-sub scope() { '' }
+sub scope { '' }
 
 =pod
 
@@ -115,7 +117,7 @@ sub add_element {
 	push @{$self->{children}}, $Element;
 	Scalar::Util::weaken(
 		$_PARENT{refaddr $Element} = $self
-	);
+		);
 
 	1;
 }
@@ -125,7 +127,7 @@ sub add_element {
 sub __add_element {
 	Scalar::Util::weaken(
 		$_PARENT{refaddr $_[1]} = $_[0]
-	);
+		);
 	push @{$_[0]->{children}}, $_[1];
 }
 
@@ -146,11 +148,7 @@ returns a count of the number of elements.
 =cut
 
 sub elements {
-	if ( wantarray ) {
-		return @{$_[0]->{children}};
-	} else {
-		return scalar @{$_[0]->{children}};
-	}
+	wantarray ? @{$_[0]->{children}} : scalar @{$_[0]->{children}};
 }
 
 =pod
@@ -223,12 +221,9 @@ returns the number of significant children.
 =cut
 
 sub schildren {
-	return grep { $_->significant } @{$_[0]->{children}} if wantarray;
-	my $count = 0;
-	foreach ( @{$_[0]->{children}} ) {
-		$count++ if $_->significant;
-	}
-	return $count;
+	my $self      = shift;
+	my @schildren = grep { $_->significant } $self->children;
+	wantarray ? @schildren : scalar(@schildren);
 }
 
 =pod
@@ -244,10 +239,7 @@ element at that node.
 =cut
 
 sub child {
-	my ( $self, $index ) = @_;
-	PPI::Exception->throw( "method child() needs an index" )
-	  if not defined _NUMBER $index;
-	$self->{children}->[$index];
+	$_[0]->{children}->[$_[1]];
 }
 
 =pod
@@ -321,7 +313,7 @@ The C<find> method is used to search within a code tree for
 L<PPI::Element> objects that meet a particular condition.
 
 To specify the condition, the method can be provided with either a simple
-class name (full or shortened), or a C<CODE>/function reference.
+class name (full or shortened), or an anonymous subroutine.
 
   # Find all single quotes in a Document (which is a Node)
   $Document->find('PPI::Quote::Single');
@@ -329,7 +321,7 @@ class name (full or shortened), or a C<CODE>/function reference.
   # The same thing with a shortened class name
   $Document->find('Quote::Single');
   
-  # Anything more elaborate, we go with the sub
+  # Anything more elaborate, we so with the sub
   $Document->find( sub {
   	# At the top level of the file...
   	$_[1]->parent == $_[0]
@@ -341,22 +333,12 @@ class name (full or shortened), or a C<CODE>/function reference.
   	)
   } );
 
-The function will be passed two arguments, the top-level C<PPI::Node>
-you are searching in and the current L<PPI::Element> that the condition
-is testing.
+The anonymous subroutine will be passed two arguments, the top-level
+Node you are searching in and the current Element that the condition is
+testing. The anonymous subroutine should return a simple true/false
+value indicating match or no match.
 
-The anonymous function should return one of three values. Returning true
-indicates a condition match, defined-false (C<0> or C<''>) indicates
-no-match, and C<undef> indicates no-match and no-descend.
-
-In the last case, the tree walker will skip over anything below the
-C<undef>-returning element and move on to the next element at the same
-level.
-
-To halt the entire search and return C<undef> immediately, a condition
-function should throw an exception (i.e. C<die>).
-
-Note that this same wanted logic is used for all methods documented to
+Note that the same wanted logic is used for all methods documented to
 have a C<\&wanted> parameter, as this one does.
 
 The C<find> method returns a reference to an array of L<PPI::Element>
@@ -369,16 +351,15 @@ In the case of a bad condition, a warning will be emitted as well.
 =cut
 
 sub find {
-	my $self   = shift;
+	my $self      = shift;
 	my $wanted = $self->_wanted(shift) or return undef;
 
 	# Use a queue based search, rather than a recursive one
-	my @found;
-	my @queue = @{$self->{children}};
-	my $ok = eval {
-		while ( @queue ) {
-			my $Element = shift @queue;
-			my $rv      = &$wanted( $self, $Element );
+	my @found = ();
+	my @queue = $self->children;
+	eval {
+		while ( my $Element = shift @queue ) {
+			my $rv = &$wanted( $self, $Element );
 			push @found, $Element if $rv;
 
 			# Support "don't descend on undef return"
@@ -391,15 +372,14 @@ sub find {
 			# better logical order.
 			if ( $Element->isa('PPI::Structure') ) {
 				unshift @queue, $Element->finish if $Element->finish;
-				unshift @queue, @{$Element->{children}};
+				unshift @queue, $Element->children;
 				unshift @queue, $Element->start if $Element->start;
 			} else {
-				unshift @queue, @{$Element->{children}};
+				unshift @queue, $Element->children;
 			}
 		}
-		1;
 	};
-	if ( !$ok ) {
+	if ( $@ ) {
 		# Caught exception thrown from the wanted function
 		return undef;
 	}
@@ -412,7 +392,7 @@ sub find {
 =head2 find_first $class | \&wanted
 
 If the normal C<find> method is like a grep, then C<find_first> is
-equivalent to the L<List::Util> C<first> function.
+equivalent to the L<Scalar::Util> C<first> function.
 
 Given an element class or a wanted function, it will search depth-first
 through a tree until it finds something that matches the condition,
@@ -427,41 +407,34 @@ or an error occurs.
 =cut
 
 sub find_first {
-	my $self   = shift;
+	my $self      = shift;
 	my $wanted = $self->_wanted(shift) or return undef;
 
 	# Use the same queue-based search as for ->find
-	my @queue = @{$self->{children}};
-	my $rv;
-	my $ok = eval {
-		# The defined() here prevents a ton of calls to PPI::Util::TRUE
-		while ( @queue ) {
-			my $Element = shift @queue;
-			my $element_rv = $wanted->( $self, $Element );
-			if ( $element_rv ) {
-				$rv = $Element;
-				last;
-			}
+	my @queue = $self->children;
+	my $rv = eval {
+		while ( my $Element = shift @queue ) {
+			my $rv = &$wanted( $self, $Element );
+			return $Element if $rv;
 
 			# Support "don't descend on undef return"
-			next if !defined $element_rv;
+			next unless defined $rv;
 
 			# Skip if the Element doesn't have any children
-			next if !$Element->isa('PPI::Node');
+			next unless $Element->isa('PPI::Node');
 
 			# Depth-first keeps the queue size down and provides a
 			# better logical order.
 			if ( $Element->isa('PPI::Structure') ) {
-				unshift @queue, $Element->finish if defined($Element->finish);
-				unshift @queue, @{$Element->{children}};
-				unshift @queue, $Element->start  if defined($Element->start);
+				unshift @queue, $Element->finish if $Element->finish;
+				unshift @queue, $Element->children;
+				unshift @queue, $Element->start  if $Element->start;
 			} else {
-				unshift @queue, @{$Element->{children}};
+				unshift @queue, $Element->children;
 			}
 		}
-		1;
 	};
-	if ( !$ok ) {
+	if ( $@ ) {
 		# Caught exception thrown from the wanted function
 		return undef;
 	}
@@ -499,8 +472,6 @@ the C<remove_element> method will remove the C<Element> intact, along
 with any of its children. As such, this method acts essentially as a
 'cut' function.
 
-If successful, returns the removed element.  Otherwise, returns C<undef>.
-
 =cut
 
 sub remove_child {
@@ -509,33 +480,18 @@ sub remove_child {
 
 	# Find the position of the child
 	my $key = refaddr $child;
-	my $p   = $self->__position($child);
+	my $p   = List::MoreUtils::firstidx {
+		refaddr $_ == $key
+		} @{$self->{children}};
 	return undef unless defined $p;
 
 	# Splice it out, and remove the child's parent entry
 	splice( @{$self->{children}}, $p, 1 );
-	delete $_PARENT{$key};
+	delete $_PARENT{refaddr $child};
 
 	$child;
 }
 
-=head2 replace_child $Element, $Replacement
-
-If successful, returns the replace element.  Otherwise, returns C<undef>.
-
-=cut
-
-sub replace_child {
-	my $self = shift;
-
-	my $child       = _INSTANCE(shift, 'PPI::Element') or return undef;
-	my $replacement = _INSTANCE(shift, 'PPI::Element') or return undef;
-
-	my $success = $self->__replace_child( $child, $replacement );
-
-	return $success ? $replacement : undef;
-}
-
 =pod
 
 =head2 prune $class | \&wanted
@@ -560,14 +516,13 @@ sub prune {
 	# Use a depth-first queue search
 	my $pruned = 0;
 	my @queue  = $self->children;
-	my $ok = eval {
+	eval {
 		while ( my $element = shift @queue ) {
 			my $rv = &$wanted( $self, $element );
 			if ( $rv ) {
 				# Delete the child
 				$element->delete or return undef;
 				$pruned++;
-				next;
 			}
 
 			# Support the undef == "don't descend"
@@ -578,9 +533,8 @@ sub prune {
 				unshift @queue, $element->children;
 			}
 		}
-		1;
 	};
-	if ( !$ok ) {
+	if ( $@ ) {
 		# Caught exception thrown from the wanted function
 		return undef;		
 	}
@@ -588,19 +542,19 @@ sub prune {
 	$pruned;
 }
 
-# This method is likely to be very heavily used, so take
-# it slowly and carefully.
+# This method is likely to be very heavily used, to take
+# it slowly and carefuly.
 ### NOTE: Renaming this function or changing either to self will probably
 ###       break File::Find::Rule::PPI
 sub _wanted {
 	my $either = shift;
-	my $it     = defined($_[0]) ? shift : do {
+	my $it     = defined $_[0] ? shift : do {
 		Carp::carp('Undefined value passed as search condition') if $^W;
 		return undef;
-	};
+		};
 
 	# Has the caller provided a wanted function directly
-	return $it if _CODELIKE($it);
+	return $it if ref $it eq 'CODE';
 	if ( ref $it ) {
 		# No other ref types are supported
 		Carp::carp('Illegal non-CODE reference passed as search condition') if $^W;
@@ -609,14 +563,14 @@ sub _wanted {
 
 	# The first argument should be an Element class, possibly in shorthand
 	$it = "PPI::$it" unless substr($it, 0, 5) eq 'PPI::';
-	unless ( _CLASS($it) and $it->isa('PPI::Element') ) {
+	unless ( UNIVERSAL::isa($it, 'PPI::Element') ) {
 		# We got something, but it isn't an element
 		Carp::carp("Cannot create search condition for '$it': Not a PPI::Element") if $^W;
 		return undef;
 	}
 
 	# Create the class part of the wanted function
-	my $wanted_class = "\n\treturn '' unless \$_[1]->isa('$it');";
+	my $wanted_class = "\n\treturn '' unless UNIVERSAL::isa( \$_[1], '$it' );";
 
 	# Have we been given a second argument to check the content
 	my $wanted_content = '';
@@ -687,7 +641,6 @@ sub location {
 # Internal Methods
 
 sub DESTROY {
-	local $_;
 	if ( $_[0]->{children} ) {
 		my @queue = $_[0];
 		while ( defined($_ = shift @queue) ) {
@@ -699,77 +652,61 @@ sub DESTROY {
 		}
 	}
 
-	$_[0]->SUPER::DESTROY;
+	# Remove us from our parent node as normal
+	delete $_PARENT{refaddr $_[0]};
 }
 
+# Find the position of a child
 sub __position {
-	my ( $self, $child ) = @_;
-	my $key = refaddr $child;
-
-	return undef unless #
-		my $elements = $self->{children};
-
-	if (defined (my $position = $_POSITION_CACHE{$key})) {
-		my $maybe_child = $elements->[$position];
-		return $position if defined $maybe_child and refaddr $maybe_child == $key;
-	}
-
-	delete $_POSITION_CACHE{$key};
-
-	$_POSITION_CACHE{refaddr $elements->[$_]} = $_ for 0 .. $#{$elements};
-
-	return $_POSITION_CACHE{$key};
+	my $key = refaddr $_[1];
+	List::MoreUtils::firstidx { refaddr $_ == $key } @{$_[0]->{children}};
 }
 
 # Insert one or more elements before a child
 sub __insert_before_child {
-	my ( $self, $child, @insertions ) = @_;
-	my $key  = refaddr $child;
-	my $p    = $self->__position($child);
-	foreach ( @insertions ) {
+	my $self = shift;
+	my $key  = refaddr shift;
+	my $p    = List::MoreUtils::firstidx {
+	         refaddr $_ == $key
+	         } @{$self->{children}};
+	foreach ( @_ ) {
 		Scalar::Util::weaken(
 			$_PARENT{refaddr $_} = $self
 			);
 	}
-	splice( @{$self->{children}}, $p, 0, @insertions );
+	splice( @{$self->{children}}, $p, 0, @_ );
 	1;
 }
 
-# Insert one or more elements after a child
+# Replace a child
 sub __insert_after_child {
-	my ( $self, $child, @insertions ) = @_;
-	my $key  = refaddr $child;
-	my $p    = $self->__position($child);
-	foreach ( @insertions ) {
+	my $self = shift;
+	my $key  = refaddr shift;
+	my $p    = List::MoreUtils::firstidx {
+	         refaddr $_ == $key
+	         } @{$self->{children}};
+	foreach ( @_ ) {
 		Scalar::Util::weaken(
 			$_PARENT{refaddr $_} = $self
 			);
 	}
-	splice( @{$self->{children}}, $p + 1, 0, @insertions );
+	splice( @{$self->{children}}, $p + 1, 0, @_ );
 	1;
 }
 
 # Replace a child
 sub __replace_child {
-	my ( $self, $old_child, @replacements ) = @_;
-	my $old_child_addr  = refaddr $old_child;
-
-	# Cache parent of new children
-	my $old_child_index = $self->__position($old_child);
-
-	return undef if !defined $old_child_index;
-
-	foreach ( @replacements ) {
+	my $self = shift;
+	my $key  = refaddr shift;
+	my $p    = List::MoreUtils::firstidx {
+	         refaddr $_ == $key
+	         } @{$self->{children}};
+	foreach ( @_ ) {
 		Scalar::Util::weaken(
 			$_PARENT{refaddr $_} = $self
 			);
 	}
-
-	# Replace old child with new children
-	splice( @{$self->{children}}, $old_child_index, 1, @replacements );
-
-	# Uncache parent of old child
-	delete $_PARENT{$old_child_addr};
+	splice( @{$self->{children}}, $p, 1, @_ );
 	1;
 }
 
@@ -812,15 +749,15 @@ sub __link_children {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
