@@ -35,18 +35,22 @@ process to be.
 =cut
 
 use strict;
-use Carp                      ();
-use List::Util 1.33           ();
-use PPI::Util                 '_Document';
+use UNIVERSAL 'isa';
+use List::MoreUtils ();
 use PPI::Document::Normalized ();
-use PPI::Normal::Standard     ();
-use PPI::Singletons           '%LAYER';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION $errstr %LAYER};
+BEGIN {
+	$VERSION = '1.001';
+	$errstr  = '';
+
+	# Registered function store
+	%LAYER = (
+		1 => [],
+		2 => [],
+		);
+}
 
-# With the registration mechanism in place, load in the main set of
-# normalization methods to initialize the store.
-PPI::Normal::Standard->import;
 
 
 
@@ -75,21 +79,18 @@ sub register {
 	while ( @_ ) {
 		# Check the function
 		my $function = shift;
-		SCOPE: {
-			no strict 'refs';
-			defined $function and defined &{"$function"}
-				or Carp::croak("Bad function name provided to PPI::Normal");
+		{ no strict 'refs';
+			defined $function and defined &{"$function"} or return undef;
 		}
 
 		# Has it already been added?
-		if ( List::Util::any { $_ eq $function } map @{$_}, values %LAYER ) {
+		if ( List::MoreUtils::any { $_ eq $function } ) {
 			return 1;
 		}
 
 		# Check the layer to add it to
 		my $layer = shift;
-		defined $layer and $layer =~ /^(?:1|2)$/
-			or Carp::croak("Bad layer provided to PPI::Normal");
+		defined $layer and $layer =~ /^(?:1|2)$/ or return undef;
 
 		# Add to the layer data store
 		push @{ $LAYER{$layer} }, $function;
@@ -98,6 +99,10 @@ sub register {
 	1;
 }
 
+# With the registration mechanism in place, load in the main set of
+# normalization methods to initialize the store.
+use PPI::Normal::Standard;
+
 
 
 
@@ -109,44 +114,33 @@ sub register {
 
 =head2 new
 
-  my $level_1 = PPI::Normal->new;
-  my $level_2 = PPI::Normal->new(2);
-
-Creates a new normalization object, to which Document objects
+Creates a new normalization level 1 object, to which Document objects
 can be passed to be normalized.
 
 Of course, what you probably REALLY want is just to call
 L<PPI::Document>'s C<normalize> method.
 
-Takes an optional single parameter of the normalisation layer
-to use, which at this time can be either "1" or "2".
+Returns a new PPI::Normal object, or C<undef> on error.
 
-Returns a new C<PPI::Normal> object, or C<undef> on error.
+B<Note>
+
+Unless it can be shown there's a string reason to make this instantiable,
+this may degrade into a non-instantiable class at a later date (although
+the PPI::Document C<normalize> will stay as is).
 
 =cut
 
 sub new {
-	my $class = shift;
-	my $layer = @_ ?
-		(defined $_[0] and ! ref $_[0] and $_[0] =~ /^[12]$/) ? shift : return undef
-		: 1;
+	my $class = shift->_clear;
 
 	# Create the object
 	my $object = bless {
-		layer => $layer,
+		layer => 2,
 		}, $class;
 
 	$object;
 }
 
-=pod
-
-=head1 layer
-
-The C<layer> accessor returns the normalisation layer of the object.
-
-=cut
-
 sub layer { $_[0]->{layer} }
 
 
@@ -156,48 +150,49 @@ sub layer { $_[0]->{layer} }
 #####################################################################
 # Main Methods
 
-=pod
-
-=head2 process
-
-The C<process> method takes anything that can be converted to a
-L<PPI::Document> (object, SCALAR ref, filename), loads it and
-applies the normalisation process to the document.
-
-Returns a L<PPI::Document::Normalized> object, or C<undef> on error.
-
-=cut
-
 sub process {
-	my $self = ref $_[0] ? shift : shift->new;
+	my $self     = ref $_[0] ? shift->_clear : shift->new;
+	my $Document = isa(ref $_[0], 'PPI::Document') ? shift : return undef;
 
-	# PPI::Normal objects are reusable, but not re-entrant
+	# Fail if object is already in use
 	return undef if $self->{Document};
 
-	# Get or create the document
-	$self->{Document} = _Document(shift) or return undef;
+	# Set up for processing run
+	$self->{Document} = $Document;
 
 	# Work out what functions we need to call
-	my @functions = map { @{ $LAYER{$_} } } ( 1 .. $self->layer );
+	my @functions = ();
+	foreach ( 1 .. $self->layer ) {
+		push @functions, @{ $LAYER{$_} };
+	}
 
 	# Execute each function
 	foreach my $function ( @functions ) {
 		no strict 'refs';
-		&{"$function"}( $self->{Document} );
+		&{"$function"}( $Document );
 	}
 
 	# Create the normalized Document object
 	my $Normalized = PPI::Document::Normalized->new(
-		Document  => $self->{Document},
-		version   => __PACKAGE__->VERSION,
+		Document  => $Document,
+		version   => $VERSION,
 		functions => \@functions,
-	) or return undef;
+		) or return undef;
 
-	# Done, clean up
-	delete $self->{Document};
-	return $Normalized;
+	$Normalized;
 }
 
+
+
+
+
+#####################################################################
+# Error Handling
+
+sub errstr { $errstr }
+sub _error { $errstr = $_[1]; undef }
+sub _clear { $errstr = ''; $_[0] }
+
 1;
 
 =pod
@@ -238,15 +233,15 @@ to the 0.900+ API of PPI only implements Layer 1 and 2 at this time.
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2011 Adam Kennedy.
+Copyright (c) 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
