@@ -17,8 +17,12 @@ B<Move along, nothing to see here>.
 =cut
 
 use strict;
+use UNIVERSAL 'isa';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -31,14 +35,14 @@ my @METHODS = (
 	remove_insignificant_elements => 1,
 	remove_useless_attributes     => 1,
 	remove_useless_pragma         => 2,
-	remove_statement_separator    => 2,
+	remove_statement_seperator    => 2,
 	remove_useless_return         => 2,
-);
+	);
 
 sub import {
 	PPI::Normal->register(
 		map { /\D/ ? "PPI::Normal::Standard::$_" : $_ } @METHODS
-	) or die "Failed to register PPI::Normal::Standard transforms";
+		) or die "Failed to register PPI::Normal::Standard transforms";
 }
 
 
@@ -84,14 +88,14 @@ sub remove_useless_pragma {
 }
 
 # Remove all semi-colons at the end of statements
-sub remove_statement_separator {
+sub remove_statement_seperator {
 	my $Document = shift;
 	$Document->prune( sub {
 		$_[1]->isa('PPI::Token::Structure') or return '';
 		$_[1]->content eq ';'               or return '';
 		my $stmt = $_[1]->parent            or return '';
 		$stmt->isa('PPI::Statement')        or return '';
-		$_[1]->next_sibling                and return '';
+		$_[1]->next_sibling                 or return '';
 		1;
 	} );
 }
@@ -120,15 +124,15 @@ sub remove_useless_return {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2011 Adam Kennedy.
+Copyright (c) 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
