@@ -27,9 +27,9 @@ frozen/finalised. Names may change slightly or be added or removed.
 
 =head2 L<PPI::Statement::Scheduled>
 
-This covers all "scheduled" blocks, chunks of code that are executed separately
-from the main body of the code, at a particular time. This includes all
-C<BEGIN>, C<CHECK>, C<UNITCHECK>, C<INIT> and C<END> blocks.
+This covers all "scheduled" blocks, chunks of code that are executed
+separately from the main body of the code, at a particular time. This
+includes all C<BEGIN>, C<CHECK>, C<INIT> and C<END> blocks.
 
 =head2 L<PPI::Statement::Package>
 
@@ -50,7 +50,7 @@ A named subroutine declaration, or forward declaration
 A variable declaration statement. This could be either a straight
 declaration or also be an expression.
 
-This includes all 'my', 'state', 'local' and 'our' statements.
+This includes all 'my', 'local' and 'out' statements.
 
 =head2 L<PPI::Statement::Compound>
 
@@ -68,17 +68,7 @@ a ';' statement terminator.
 
 A statement that breaks out of a structure.
 
-This includes all of 'redo', 'goto', 'next', 'last' and 'return' statements.
-
-=head2 L<PPI::Statement::Given>
-
-The kind of statement introduced in Perl 5.10 that starts with 'given'.  This
-has an implicit end.
-
-=head2 L<PPI::Statement::When>
-
-The kind of statement introduced in Perl 5.10 that starts with 'when' or
-'default'.  This also has an implicit end.
+This includes all of 'redo', 'next', 'last' and 'return' statements.
 
 =head2 L<PPI::Statement::Data>
 
@@ -147,16 +137,8 @@ of the methods that are subclass-specific.
 =cut
 
 use strict;
-use Scalar::Util   ();
-use Params::Util   qw{_INSTANCE};
-use PPI::Node      ();
-use PPI::Exception ();
-use PPI::Singletons '%_PARENT';
-
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Node";
-
+use UNIVERSAL 'isa';
+use base 'PPI::Node';
 use PPI::Statement::Break          ();
 use PPI::Statement::Compound       ();
 use PPI::Statement::Data           ();
@@ -167,16 +149,19 @@ use PPI::Statement::Null           ();
 use PPI::Statement::Package        ();
 use PPI::Statement::Scheduled      ();
 use PPI::Statement::Sub            ();
-use PPI::Statement::Given         ();
 use PPI::Statement::UnmatchedBrace ();
 use PPI::Statement::Unknown        ();
 use PPI::Statement::Variable       ();
-use PPI::Statement::When           ();
+
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 # "Normal" statements end at a statement terminator ;
-# Some are not, and need the more rigorous _continues to see
+# Some are not, and need the more rigorous _statement_continues to see
 # if we are at an implicit statement boundary.
-sub __LEXER__normal() { 1 }
+sub __LEXER__normal { 1 }
 
 
 
@@ -186,24 +171,16 @@ sub __LEXER__normal() { 1 }
 # Constructor
 
 sub new {
-	my $class = shift;
-	if ( ref $class ) {
-		PPI::Exception->throw;
-	}
-
+	my $class = ref $_[0] ? ref shift : shift;
+	
 	# Create the object
 	my $self = bless { 
 		children => [],
-	}, $class;
+		}, $class;
 
-	# If we have been passed what should be an initial token, add it
-	my $token = shift;
-	if ( _INSTANCE($token, 'PPI::Token') ) {
-		# Inlined $self->__add_element(shift);
-		Scalar::Util::weaken(
-			$_PARENT{Scalar::Util::refaddr $token} = $self
-		);
-		push @{$self->{children}}, $token;
+	# If we have been passed an initial token, add it
+	if ( isa(ref $_[0], 'PPI::Token') ) {
+		$self->__add_element(shift);
 	}
 
 	$self;
@@ -213,7 +190,7 @@ sub new {
 
 =head2 label
 
-One factor common to most statements is their ability to be labeled.
+One factor common to most statements is their ability to be labelled.
 
 The C<label> method returns the label for a statement, if one has been
 defined, but without the trailing colon. Take the following example
@@ -227,33 +204,14 @@ Returns false if the statement does not have a label.
 =cut
 
 sub label {
-	my $first = shift->schild(1) or return '';
-	$first->isa('PPI::Token::Label')
+	my $first = shift->schild(1);
+	isa($first, 'PPI::Token::Label')
 		? substr($first, 0, length($first) - 1)
 		: '';
 }
 
 =pod
 
-=head2 specialized
-
-Answer whether this is a plain statement or one that has more
-significance.
-
-Returns true if the statement is a subclass of this one, false
-otherwise.
-
-=cut
-
-# Yes, this is doing precisely what it's intending to prevent
-# client code from doing.  However, since it's here, if the
-# implementation changes, code outside PPI doesn't care.
-sub specialized {
-	__PACKAGE__ ne ref $_[0];
-}
-
-=pod
-
 =head2 stable
 
 Much like the L<PPI::Document> method of the same name, the ->stable
@@ -267,6 +225,7 @@ error.
 =cut
 
 sub stable {
+	my $self = shift;
 	die "The ->stable method has not yet been implemented";	
 }
 
@@ -277,24 +236,10 @@ sub stable {
 #####################################################################
 # PPI::Element Methods
 
-# Is the statement complete.
-# By default for a statement, we need a semi-colon at the end.
-sub _complete {
-	my $self = shift;
-	my $semi = $self->schild(-1);
-	return !! (
-		defined $semi
-		and
-		$semi->isa('PPI::Token::Structure')
-		and
-		$semi->content eq ';'
-	);
-}
-
-# You can insert either a statement or a non-significant token.
+# You can insert either a statement, or a non-significant token.
 sub insert_before {
 	my $self    = shift;
-	my $Element = _INSTANCE(shift, 'PPI::Element') or return undef;
+	my $Element = isa($_[0], 'PPI::Element') or return undef;
 	if ( $Element->isa('PPI::Statement') ) {
 		return $self->__insert_before($Element);
 	} elsif ( $Element->isa('PPI::Token') and ! $Element->significant ) {
@@ -306,7 +251,7 @@ sub insert_before {
 # As above, you can insert a statement, or a non-significant token
 sub insert_after {
 	my $self    = shift;
-	my $Element = _INSTANCE(shift, 'PPI::Element') or return undef;
+	my $Element = isa($_[0], 'PPI::Element') or return undef;
 	if ( $Element->isa('PPI::Statement') ) {
 		return $self->__insert_after($Element);
 	} elsif ( $Element->isa('PPI::Token') and ! $Element->significant ) {
@@ -315,6 +260,25 @@ sub insert_after {
 	'';
 }
 
+
+
+
+
+#####################################################################
+# Support Methods
+
+sub _Fragment {
+	my $self = shift;
+
+	# Because we are potentially part of a larger structure,
+	# we need to clone ourselves first.
+	my $clone = $self->clone or return undef;
+
+	# Create the empty Fragment
+	my $Fragment = PPI::Document::Fragment->new;
+	$Fragment->add_element( $self ) or return undef;
+}
+
 1;
 
 =pod
@@ -325,15 +289,15 @@ sub insert_after {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
