@@ -12,11 +12,10 @@ PPI::Statement::Break - Statements which break out of normal statement flow
   goto FOO;
   next if condition();
   return $foo;
-  redo;
 
 =head1 INHERITANCE
 
-  PPI::Statement::Break
+  PPI::Statement::Compound
   isa PPI::Statement
       isa PPI::Node
           isa PPI::Element
@@ -24,8 +23,8 @@ PPI::Statement::Break - Statements which break out of normal statement flow
 =head1 DESCRIPTION
 
 C<PPI::Statement::Break> is intended to represent statements that break
-out of the normal statement flow control. This covers the basic
-types C<'redo'>, C<'goto'>, C<'next'>, C<'last'> and C<'return'>.
+out of the normal statement flow control. This covers the four basic
+types C<'goto'>, C<'next'>, C<'last'> and C<'return'>.
 
 =head1 METHODS
 
@@ -38,11 +37,12 @@ to, or the structure to break out of.
 =cut
 
 use strict;
-use PPI::Statement ();
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -56,15 +56,15 @@ our @ISA = "PPI::Statement";
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
