@@ -12,7 +12,7 @@ PPI::Statement::End - Content after the __END__ of a module
   
   __END__
   
-  This is part of a PPI::Statement::End statement
+  This is part of an PPI::Statement::End statement
   
   =pod
   
@@ -45,14 +45,12 @@ provided by L<PPI::Statement>, L<PPI::Node> and L<PPI::Element>.
 =cut
 
 use strict;
-use PPI::Statement ();
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
-
-# Once we have an __END__ we're done
-sub _complete () { 1 }
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -60,15 +58,15 @@ sub _complete () { 1 }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
