@@ -30,17 +30,18 @@ classes.
 
 =head1 METHODS
 
-C<PPI::Statement::Expression> has no additional methods beyond the default ones
+C<PPI::Statement::Null> has no additional methods beyond the default ones
 provided by L<PPI::Statement>, L<PPI::Node> and L<PPI::Element>.
 
 =cut
 
 use strict;
-use PPI::Statement ();
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -48,15 +49,15 @@ our @ISA = "PPI::Statement";
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
