@@ -24,9 +24,9 @@ PPI::Statement::Null - A useless null statement
 =head1 DESCRIPTION
 
 C<PPI::Statement::Null> is a utility class designed to handle situations
-where PPI encounters a naked statement separator.
+where PPI encounters a naked statement seperator.
 
-Although strictly speaking, the semicolon is a statement B<separator>
+Although strictly speaking, the semicolon is a statement B<seperator>
 and not a statement B<terminator>, PPI considers a semicolon to be a
 statement terminator under most circumstances.
 
@@ -41,14 +41,15 @@ provided by L<PPI::Statement>, L<PPI::Node> and L<PPI::Element>.
 =cut
 
 use strict;
-use PPI::Statement ();
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 # A null statement is not significant
-sub significant() { '' }
+sub significant { '' }
 
 1;
 
@@ -56,15 +57,15 @@ sub significant() { '' }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
