@@ -39,14 +39,13 @@ L<PPI::Statement>, L<PPI::Node> and L<PPI::Element> methods.
 =cut
 
 use strict;
-use PPI::Statement ();
+use UNIVERSAL 'isa';
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
-
-# Lexer clues
-sub __LEXER__normal() { '' }
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 =pod
 
@@ -67,31 +66,7 @@ If the package statement is done any different way, it returns false.
 sub namespace {
 	my $self = shift;
 	my $namespace = $self->schild(1) or return '';
-	$namespace->isa('PPI::Token::Word')
-		? $namespace->content
-		: '';
-}
-
-=pod
-
-=head2 version
-
-Some package declarations may include a version:
-
-  package Foo::Bar 1.23;
-  package Baz v1.23;
-
-The C<version> method returns the stringified version as seen in the
-document (if any), otherwise the empty string.
-
-=cut
-
-sub version {
-	my $self = shift;
-	my $version = $self->schild(2) or return '';
-	$version->isa('PPI::Token::Structure')
-		? ''
-		: $version->content;
+	isa($namespace, 'PPI::Token::Word') ? $namespace->content : '';
 }
 
 =pod
@@ -116,8 +91,8 @@ sub file_scoped {
 	my $self     = shift;
 	my ($Parent, $Document) = ($self->parent, $self->top);
 	$Parent and $Document and $Parent == $Document
-	and $Document->isa('PPI::Document')
-	and ! $Document->isa('PPI::Document::Fragment');
+	and isa($Document, 'PPI::Document')
+	and ! isa($Document, 'PPI::Document::Fragment');
 }
 
 1;
@@ -126,15 +101,15 @@ sub file_scoped {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
