@@ -9,38 +9,32 @@ PPI::Statement::Scheduled - A scheduled code block
 =head1 INHERITANCE
 
   PPI::Statement::Scheduled
-  isa PPI::Statement::Sub
-      isa PPI::Statement
-          isa PPI::Node
-              isa PPI::Element
+  isa PPI::Statement
+      isa PPI::Node
+          isa PPI::Element
 
 =head1 DESCRIPTION
 
 A scheduled code block is one that is intended to be run at a specific
 time during the loading process.
 
-There are five types of scheduled block:
+There are four types of scheduled block:
 
   BEGIN {
   	# Executes as soon as this block is fully defined
   	...
   }
-
+  
   CHECK {
-  	# Executes after overall compile-phase in reverse order
+  	# Executes after compile-phase in reverse order
   	...
   }
-
-  UNITCHECK {
-  	# Executes after compile-phase of individual module in reverse order
-  	...
-  }
-
+  
   INIT {
   	# Executes just before run-time
   	...
   }
-
+  
   END {
   	# Executes as late as possible in reverse order
   	...
@@ -54,31 +48,22 @@ may have 'sub' in front of them.
 =cut
 
 use strict;
-use PPI::Statement::Sub ();
+use UNIVERSAL 'isa';
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement::Sub";
-
-sub __LEXER__normal() { '' }
-
-sub _complete {
-	my $child = $_[0]->schild(-1);
-	return !! (
-		defined $child
-		and
-		$child->isa('PPI::Structure::Block')
-		and
-		$child->complete
-	);
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
 }
 
+sub __LEXER__normal { '' }
+
 =pod
 
 =head2 type
 
 The C<type> method returns the type of scheduled block, which should always be
-one of C<'BEGIN'>, C<'CHECK'>, C<'UNITCHECK'>, C<'INIT'> or C<'END'>.
+one of C<'BEGIN'>, C<'CHECK'>, C<'INIT'> or C<'END'>.
 
 =cut
 
@@ -90,9 +75,23 @@ sub type {
 		: $children[0]->content;
 }
 
-# This is actually the same as Sub->name
-sub name {
-	shift->type(@_);
+=pod
+
+=head2 block
+
+With its name and implementation shared with L<PPI::Statement::Sub>, the
+C<block> method finds and returns the actual Structure object of the block
+for this scheduled block.
+
+Returns false if it cannot find a block (although why this might happen
+I'm not sure).
+
+=cut
+
+sub block {
+	my $self = shift;
+	my $lastchild = $self->schild(-1);
+	isa($lastchild, 'PPI::Structure::Block') and $lastchild;
 }
 
 1;
@@ -105,15 +104,15 @@ sub name {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
