@@ -15,9 +15,9 @@ PPI::Statement::Sub - Subroutine declaration
 
 =head1 DESCRIPTION
 
-Except for the special BEGIN, CHECK, UNITCHECK, INIT, and END subroutines
-(which are part of L<PPI::Statement::Scheduled>) all subroutine declarations
-are lexed as a PPI::Statement::Sub object.
+Except for the special BEGIN, CHECK, INIT, and END subroutines (which are
+part of L<PPI::Statement::Scheduled>) all subroutine declarations are lexed
+as a PPI::Statement::Sub object.
 
 Primarily, this means all of the various C<sub foo {}> statements, but also
 forward declarations such as C<sub foo;> or C<sub foo($);>. It B<does not>
@@ -31,27 +31,17 @@ L<PPI::Statement>, L<PPI::Node> and L<PPI::Element> methods.
 =cut
 
 use strict;
-use List::Util     ();
-use Params::Util   qw{_INSTANCE};
-use PPI::Statement ();
+use UNIVERSAL 'isa';
+use base 'PPI::Statement';
+use List::Util ();
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 # Lexer clue
-sub __LEXER__normal() { '' }
-
-sub _complete {
-	my $child = $_[0]->schild(-1);
-	return !! (
-		defined $child
-		and
-		$child->isa('PPI::Structure::Block')
-		and
-		$child->complete
-	);
-}
+sub __LEXER__normal { '' }
 
 
 
@@ -72,20 +62,11 @@ false.
 =cut
 
 sub name {
-	my ($self) = @_;
+	my $self = shift;
 
-	# Usually the second token is the name.
-	# The third token is the name if this is a lexical subroutine.
-	my $token = $self->schild(defined $self->type ? 2 : 1);
-	return $token->content
-	  if defined $token and $token->isa('PPI::Token::Word');
-
-	# In the case of special subs whose 'sub' can be omitted (AUTOLOAD
-	# or DESTROY), the name will be the first token.
-	$token = $self->schild(0);
-	return $token->content
-	  if defined $token and $token->isa('PPI::Token::Word');
-	return '';
+	# The second token should be the name, if we have one
+	my $Token = $self->schild(1) or return undef;
+	isa($Token, 'PPI::Token::Word') ? $Token->content : '';
 }
 
 =pod
@@ -96,18 +77,14 @@ If it has one, the C<prototype> method returns the subroutine's prototype.
 It is returned in the same format as L<PPI::Token::Prototype/prototype>,
 cleaned and removed from its brackets.
 
-Returns the subroutine's prototype, or undef if the subroutine does not
-define one. Note that when the sub has an empty prototype (C<()>) the
-return is an empty string.
+Returns false if the subroutine does not define a prototype
 
 =cut
 
 sub prototype {
-	my $self      = shift;
-	my $Prototype = List::Util::first {
-		_INSTANCE($_, 'PPI::Token::Prototype')
-	} $self->children;
-	defined($Prototype) ? $Prototype->prototype : undef;
+	my $self = shift;
+	my $Prototype = List::Util::first { isa($_, 'PPI::Token::Prototype') } $self->children;
+	defined($Prototype) ? $Prototype->prototype : '';
 }
 
 =pod
@@ -125,8 +102,8 @@ code block.
 
 sub block {
 	my $self = shift;
-	my $lastchild = $self->schild(-1) or return '';
-	$lastchild->isa('PPI::Structure::Block') and $lastchild;
+	my $lastchild = $self->schild(-1);
+	isa($lastchild, 'PPI::Structure::Block') and $lastchild;
 }
 
 =pod
@@ -154,8 +131,8 @@ if this is a special reserved subroutine. It does not check against any
 particular list of reserved sub names, but just returns true if the name
 is all uppercase, as defined in L<perlsub>.
 
-Note that in the case of BEGIN, CHECK, UNITCHECK, INIT and END, these will be
-defined as L<PPI::Statement::Scheduled> objects, not subroutines.
+Note that in the case of BEGIN, CHECK, INIT and END, these will be defined
+as L<PPI::Statement::Scheduled> objects, not subroutines.
 
 Returns true if it is a special reserved subroutine, or false if not.
 
@@ -164,54 +141,28 @@ Returns true if it is a special reserved subroutine, or false if not.
 sub reserved {
 	my $self = shift;
 	my $name = $self->name or return '';
-	# perlsub is silent on whether reserveds can contain:
-	# - underscores;
-	# we allow them due to existing practice like CLONE_SKIP and __SUB__.
-	# - numbers; we allow them by PPI tradition.
 	$name eq uc $name;
 }
 
-=pod
-
-=head2 type
-
-The C<type> method checks and returns the declaration type of the statement,
-which will be one of 'my', 'our', or 'state'.
-
-Returns a string of the type, or C<undef> if the type is not declared.
-
-=cut
-
-sub type {
-	my $self = shift;
-
-	# Get the first significant child
-	my @schild = grep { $_->significant } $self->children;
-
-	# Ignore labels
-	shift @schild if _INSTANCE($schild[0], 'PPI::Token::Label');
-
-	# Get the type
-	(_INSTANCE($schild[0], 'PPI::Token::Word') and $schild[0]->content =~ /^(my|our|state)$/)
-		? $schild[0]->content
-		: undef;
-}
-
 1;
 
 =pod
 
+=head1 TO DO
+
+- Write unit tests for this package
+
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
