@@ -33,15 +33,12 @@ L<PPI::Element>.
 =cut
 
 use strict;
-use PPI::Statement ();
+use base 'PPI::Statement';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Statement";
-
-# If one of these ends up in the final document,
-# we're pretty much screwed. Just call it a day.
-sub _complete () { 1 }
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -49,15 +46,15 @@ sub _complete () { 1 }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
