@@ -38,14 +38,18 @@ and any other block braces.
 C<PPI::Structure::Block> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Structure ();
+use UNIVERSAL 'isa';
+use base 'PPI::Structure';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Structure";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -55,7 +59,7 @@ our @ISA = "PPI::Structure";
 # PPI::Element Methods
 
 # This is a scope boundary
-sub scope() { 1 }
+sub scope { 1 }
 
 1;
 
@@ -63,15 +67,15 @@ sub scope() { 1 }
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
