@@ -28,14 +28,17 @@ reference of C<HASH> reference constructors.
 C<PPI::Structure::Constructor> has no methods beyond those provided by
 the standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Structure ();
+use base 'PPI::Structure';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Structure";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -43,15 +46,15 @@ our @ISA = "PPI::Structure";
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
