@@ -4,7 +4,7 @@ package PPI::Structure::List;
 
 =head1 NAME
 
-PPI::Structure::List - Explicit list or precedence ordering braces
+PPI::Structure::List - An explicit list or scoping brace
 
 =head1 SYNOPSIS
 
@@ -31,35 +31,16 @@ represent lists, and related.
 C<PPI::Structure::List> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use Carp           ();
-use PPI::Structure ();
+use base 'PPI::Structure';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Structure";
-
-# Highly special custom isa method that will continue to respond
-# positively to ->isa('PPI::Structure::ForLoop') but warns.
-my $has_warned = 0;
-sub isa {
-	if ( $_[1] and $_[1] eq 'PPI::Structure::ForLoop' ) {
-		if (
-			$_[0]->parent->isa('PPI::Statement::Compound')
-			and
-			$_[0]->parent->type =~ /^for/
-		) {
-			unless ( $has_warned ) {
-				local $Carp::CarpLevel = $Carp::CarpLevel + 1;
-				Carp::carp("PPI::Structure::ForLoop has been deprecated");
-				$has_warned = 1;
-			}
-			return 1;
-		}
-	}
-	return shift->SUPER::isa(@_);
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
 }
 
 1;
@@ -68,15 +49,15 @@ sub isa {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
