@@ -21,29 +21,22 @@ a L<PPI::Element> that directly represents bytes of source code.
 =cut
 
 use strict;
-use Params::Util   qw{_INSTANCE};
-use PPI::Element   ();
-use PPI::Exception ();
+use UNIVERSAL 'isa';
+use base 'PPI::Element';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = 'PPI::Element';
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 # We don't load the abstracts, they are loaded
-# as part of the inheritance process.
+# as part of the 'use base' statements.
 
 # Load the token classes
-use PPI::Token::BOM                   ();
 use PPI::Token::Whitespace            ();
 use PPI::Token::Comment               ();
 use PPI::Token::Pod                   ();
 use PPI::Token::Number                ();
-use PPI::Token::Number::Binary        ();
-use PPI::Token::Number::Octal         ();
-use PPI::Token::Number::Hex           ();
-use PPI::Token::Number::Float         ();
-use PPI::Token::Number::Exp           ();
-use PPI::Token::Number::Version       ();
 use PPI::Token::Word                  ();
 use PPI::Token::DashedWord            ();
 use PPI::Token::Symbol                ();
@@ -81,12 +74,26 @@ use PPI::Token::Unknown               ();
 # Constructor and Related
 
 sub new {
-	bless { content => (defined $_[1] ? "$_[1]" : '') }, $_[0];
+	if ( @_ == 2 ) {
+		# PPI::Token->new( $content );
+		my $class = $_[0] eq __PACKAGE__ ? 'PPI::Token::Whitespace' : shift;
+		return bless {
+			content => (defined $_[0] ? "$_[0]" : '')
+			}, $class;
+	} elsif ( @_ == 3 ) {
+		# PPI::Token->new( $class, $content );
+		my $class = substr( $_[0], 0, 12 ) eq 'PPI::Token::' ? $_[1] : "PPI::Token::$_[1]";
+		return bless {
+			content => (defined $_[2] ? "$_[2]" : '')
+			},  $class;
+	}
+
+	# Invalid argument count
+	undef;
 }
 
 sub set_class {
-	my $self  = shift;
-	# @_ or throw Exception("No arguments to set_class");
+	my $self  = shift; @_ or return undef;
 	my $class = substr( $_[0], 0, 12 ) eq 'PPI::Token::' ? shift : 'PPI::Token::' . shift;
 
 	# Find out if the current and new classes are complex
@@ -99,15 +106,15 @@ sub set_class {
 	# If we are changing to or from a Quote style token, we
 	# can't just rebless and need to do some extra thing
 	# Otherwise, we have done enough
-	return $class if ($old_quote - $new_quote) == 0;
+	return 1 if ($old_quote - $new_quote) == 0;
 
 	# Make a new token from the old content, and overwrite the current
 	# token's attributes with the new token's attributes.
-	my $token = $class->new( $self->{content} );
-	%$self = %$token;
+	my $token = $class->new( $self->{content} ) or return undef;
+	delete $self->{$_} foreach keys %$self;
+	$self->{$_} = $token->{$_} foreach keys %$token;
 
-	# Return the class as a convenience
-	return $class;
+	1;
 }
 
 
@@ -121,7 +128,7 @@ sub set_class {
 
 =head2 set_content $string
 
-The C<set_content> method allows you to set/change the string that the
+The C<set_content> method allows to set/change the string that the
 C<PPI::Token> object represents.
 
 Returns the string you set the Token to
@@ -153,7 +160,7 @@ The C<length> method returns the length of the string in a Token.
 
 =cut
 
-sub length { CORE::length($_[0]->{content}) }
+sub length { &CORE::length($_[0]->{content}) }
 
 
 
@@ -169,7 +176,7 @@ sub content {
 # You can insert either a statement, or a non-significant token.
 sub insert_before {
 	my $self    = shift;
-	my $Element = _INSTANCE(shift, 'PPI::Element')  or return undef;
+	my $Element = isa($_[0], 'PPI::Element') or return undef;
 	if ( $Element->isa('PPI::Structure') ) {
 		return $self->__insert_before($Element);
 	} elsif ( $Element->isa('PPI::Token') ) {
@@ -181,7 +188,7 @@ sub insert_before {
 # As above, you can insert a statement, or a non-significant token
 sub insert_after {
 	my $self    = shift;
-	my $Element = _INSTANCE(shift, 'PPI::Element') or return undef;
+	my $Element = isa($_[0], 'PPI::Element') or return undef;
 	if ( $Element->isa('PPI::Structure') ) {
 		return $self->__insert_after($Element);
 	} elsif ( $Element->isa('PPI::Token') ) {
@@ -197,9 +204,9 @@ sub insert_after {
 #####################################################################
 # Tokenizer Methods
 
-sub __TOKENIZER__on_line_start() { 1 }
-sub __TOKENIZER__on_line_end()   { 1 }
-sub __TOKENIZER__on_char()       { 'Unknown' }
+sub __TOKENIZER__on_line_start { 1 }
+sub __TOKENIZER__on_line_end   { 1 }
+sub __TOKENIZER__on_char       { 'Unknown' }
 
 
 
@@ -221,25 +228,3 @@ sub __LEXER__closes {
 }
 
 1;
-
-=pod
-
-=head1 SUPPORT
-
-See the L<support section|PPI/SUPPORT> in the main module.
-
-=head1 AUTHOR
-
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2001 - 2011 Adam Kennedy.
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
-=cut
