@@ -28,14 +28,19 @@ treated by Perl (and thus by us) as a single string.
 This class provides some additional methods beyond those provided by its
 L<PPI::Token> and L<PPI::Element> parent classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
-our @ISA = "PPI::Token";
 
 
 
@@ -63,13 +68,13 @@ sub identifier {
 
 =head2 parameters
 
-The C<parameters> method returns the parameter string for the attribute.
+The C<parameters> method returns the parameter strong for the attribute.
 
 That is, for the attribute C<foo(bar)>, the C<parameters> method would
 return C<"bar">.
 
 Returns the parameters as a string (including the null string C<''> for
-the case of an attribute such as C<foo()>.)
+the case of an attribute such as C<foo()>.
 
 Returns C<undef> if the attribute does not have parameters.
 
@@ -77,7 +82,7 @@ Returns C<undef> if the attribute does not have parameters.
 
 sub parameters {
 	my $self = shift;
-	$self->{content} =~ /\((.*)\)$/ ? $1 : undef;
+	$self->{content} =~ /\((.+)\)$/ ? $1 : undef;
 }
 
 
@@ -89,8 +94,8 @@ sub parameters {
 
 sub __TOKENIZER__on_char {
 	my $class = shift;
-	my $t     = shift;
-	my $char  = substr( $t->{line}, $t->{line_cursor}, 1 );
+	my $t = shift;
+	my $char = substr( $t->{line}, $t->{line_cursor}, 1 );
 
 	# Unless this is a '(', we are finished.
 	unless ( $char eq '(' ) {
@@ -106,11 +111,12 @@ sub __TOKENIZER__on_char {
 		# EOF
 		$t->{token}->{content} .= $$string;
 		$t->_finalize_token;
-		return 0;
+		return '';
 	}
 
 	# Found the end of the attribute
 	$t->{token}->{content} .= $string;
+	$t->{token}->{_attribute} = 1;
 	$t->_finalize_token->__TOKENIZER__on_char( $t );
 }
 
@@ -125,13 +131,15 @@ sub __TOKENIZER__scan_for_end {
 	my $depth = 0;
 	while ( exists $t->{line} ) {
 		# Get the search area
-		pos $t->{line} = $t->{line_cursor};
+		$_ = $t->{line_cursor}
+			? substr( $t->{line}, $t->{line_cursor} )
+			: $t->{line};
 
 		# Look for a match
-		unless ( $t->{line} =~ /\G((?:\\.|[^()])*?[()])/gc ) {
-			# Load in the next line and push to first character
-			$string .= substr( $t->{line}, $t->{line_cursor} );
-			$t->_fill_line(1) or return \$string;
+		unless ( /^(.*?(?:\(|\)))/ ) {
+			# Load in the next line
+			$string .= $_;
+			return undef unless defined $t->_fill_line;
 			$t->{line_cursor} = 0;
 			next;
 		}
@@ -140,7 +148,7 @@ sub __TOKENIZER__scan_for_end {
 		$string .= $1;
 		$t->{line_cursor} += length $1;
 
-		# Alter the depth and continue if we aren't at the end
+		# Alter the depth and continue if we arn't at the end
 		$depth += ($1 =~ /\($/) ? 1 : -1 and next;
 
 		# Found the end
@@ -157,15 +165,15 @@ sub __TOKENIZER__scan_for_end {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
