@@ -27,21 +27,19 @@ represents a cast. In this case, an array dereference.
 There are no additional methods beyond those provided by the parent
 L<PPI::Token> and L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
-our @ISA = "PPI::Token";
-
-our %POSTFIX = map { $_ => 1 } (
-	qw{
-	%* @* $*
-	},
-	'$#*' # throws warnings if it's inside a qw
-);
 
 
 
@@ -50,16 +48,8 @@ our %POSTFIX = map { $_ => 1 } (
 # Tokenizer Methods
 
 # A cast is either % @ $ or $#
-# and also postfix dereference are %* @* $* $#*
 sub __TOKENIZER__on_char {
-	my $t    = $_[1];
-	my $char = substr( $t->{line}, $t->{line_cursor}, 1 );
-
-	# Are we still an operator if we add the next character
-	my $content = $t->{token}->{content};
-	return 1 if $POSTFIX{ $content . $char };
-
-	$t->_finalize_token->__TOKENIZER__on_char( $t );
+	$_[1]->_finalize_token->__TOKENIZER__on_char( $_[1] );
 }
 
 1;
@@ -68,15 +58,15 @@ sub __TOKENIZER__on_char {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
