@@ -28,7 +28,7 @@ In PPI, comments are represented by C<PPI::Token::Comment> objects.
 
 These come in two flavours, line comment and inline comments.
 
-A C<line comment> is a comment that stands on its own line. These comments
+A line comment is a comment that stands on it's own line. These comments
 hold their own newline and whitespace (both leading and trailing) as part
 of the one C<PPI::Token::Comment> object.
 
@@ -41,7 +41,7 @@ This is largely a convenience, simplifying a lot of normal code relating
 to the common things people do with comments.
 
 Most commonly, it means when you C<prune> or C<delete> a comment, a line
-comment disappears taking the entire line with it, and an inline comment
+comment disapears taking the entire line with it, and an inline comment
 is removed from the inside of the line, allowing the newline to drop
 back onto the end of the code, as you would expect.
 
@@ -59,14 +59,16 @@ parent L<PPI::Token> and L<PPI::Element> classes.
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 ### XS -> PPI/XS.xs:_PPI_Token_Comment__significant 0.900+
-sub significant() { '' }
+sub significant { '' }
 
 # Most stuff goes through __TOKENIZER__commit.
 # This is such a rare case, do char at a time to keep the code small
@@ -85,14 +87,14 @@ sub __TOKENIZER__commit {
 	my $t = $_[1];
 
 	# Get the rest of the line
-	my $rest = substr( $t->{line}, $t->{line_cursor} );
-	if ( chomp $rest ) { # Include the newline separately
+	$_ = substr( $t->{line}, $t->{line_cursor} );
+	if ( chomp ) { # Include the newline separately
 		# Add the current token, and the newline
-		$t->_new_token('Comment', $rest);
+		$t->_new_token('Comment', $_);
 		$t->_new_token('Whitespace', "\n");
 	} else {
 		# Add this token only
-		$t->_new_token('Comment', $rest);
+		$t->_new_token('Comment', $_);
 	}
 
 	# Advance the line cursor to the end
@@ -127,15 +129,15 @@ sub line {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
