@@ -16,33 +16,25 @@ PPI::Token::DashedWord - A dashed bareword token
 
 The "dashed bareword" token represents literal values like C<-foo>.
 
-NOTE: this class is currently unused.  All tokens that should be
-PPI::Token::DashedWords are just normal PPI::Token::Word instead.
-That actually makes sense, since there really is nothing special about
-this class except that dashed words cannot be subroutine names or
-keywords.  As such, this class may be removed from PPI in the future.
-
 =head1 METHODS
 
+There are no additional methods beyond those provided by the parent
+L<PPI::Token> and L<PPI::Element> classes.
+
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
-our @ISA = "PPI::Token";
 
-=pod
-
-=head2 literal
-
-Returns the value of the dashed word as a string.  This differs from
-C<content> because C<-Foo'Bar> expands to C<-Foo::Bar>.
-
-=cut
-
-*literal = *PPI::Token::Word::literal;
 
 
 
@@ -53,8 +45,8 @@ sub __TOKENIZER__on_char {
 	my $t = $_[1];
 
 	# Suck to the end of the dashed bareword
-	pos $t->{line} = $t->{line_cursor};
-	if ( $t->{line} =~ m/\G(\w+)/gc ) {
+	my $line = substr( $t->{line}, $t->{line_cursor} );
+	if ( $line =~ /^(\w+)/ ) {
 		$t->{token}->{content} .= $1;
 		$t->{line_cursor} += length $1;
 	}
@@ -62,10 +54,10 @@ sub __TOKENIZER__on_char {
 	# Are we a file test operator?
 	if ( $t->{token}->{content} =~ /^\-[rwxoRWXOezsfdlpSbctugkTBMAC]$/ ) {
 		# File test operator
-		$t->{class} = $t->{token}->set_class( 'Operator' );
+		$t->_set_token_class( 'Operator' ) or return undef;
 	} else {
 		# No, normal dashed bareword
-		$t->{class} = $t->{token}->set_class( 'Word' );
+		$t->_set_token_class( 'Word' ) or return undef;
 	}
 
 	$t->_finalize_token->__TOKENIZER__on_char( $t );
@@ -77,15 +69,15 @@ sub __TOKENIZER__on_char {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
