@@ -15,7 +15,7 @@ PPI::Token::Data - The actual data in the __DATA__ section of a file
 =head1 DESCRIPTION
 
 The C<PPI::Token::Data> class is used to represent the actual data inside
-a file's C<__DATA__> section.
+of a file's __DATA__ section.
 
 One C<PPI::Token::Data> object is used to represent the entire of the data,
 primarily so that it can provide a convenient handle directly to the data.
@@ -28,19 +28,14 @@ our parent L<PPI::Token> and L<PPI::Element> classes.
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
+use IO::Scalar ();
 
-# IO::String emulates file handles using in memory strings. Perl can do this
-# directly on perl 5.8+
-use constant USE_IO_STRING => $] < '5.008000';
-use if USE_IO_STRING, 'IO::String';
-# code may expect methods to be available on all file handles, so make sure
-# IO is loaded
-use if !USE_IO_STRING, 'IO::File';
-
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -53,43 +48,24 @@ our @ISA = "PPI::Token";
 
 =head2 handle
 
-The C<handle> method returns a L<IO::String> handle that allows you
-to do all the normal handle-y things to the contents of the __DATA__
+The C<handle> method returns a L<IO::Scalar> handle that allows you
+to do all the normal handle'y things to the contents of the __DATA__
 section of the file.
 
 Unlike in perl itself, this means you can also do things like C<print>
 new data onto the end of the __DATA__ section, or modify it with
 any other process that can accept an L<IO::Handle> as input or output.
 
-Returns an L<IO::String> object.
+Returns an L<IO::Scalar> object
 
 =cut
 
 sub handle {
 	my $self = shift;
-	# perl 5.6 compatibility
-	if (USE_IO_STRING) {
-		return IO::String->new( \$self->{content} );
-	}
-	else {
-		open my $fh, '+<', \$self->{content};
-		return $fh;
-	}
+	IO::Scalar->new( \$self->{content} );
 }
 
-sub __TOKENIZER__on_line_start {
-	my ( $self, $t ) = @_;
-
-	# Add the line
-	if ( defined $t->{token} ) {
-		$t->{token}->{content} .= $t->{line};
-	}
-	else {
-		defined( $t->{token} = $t->{class}->new( $t->{line} ) ) or return undef;
-	}
-
-	return 0;
-}
+sub __TOKENIZER__on_char { 1 }
 
 1;
 
@@ -97,15 +73,15 @@ sub __TOKENIZER__on_line_start {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
