@@ -17,9 +17,9 @@ PPI::Token::End - Completely useless content after the __END__ tag
 If you've read L<PPI::Token::Whitespace>, you should understand by now
 the concept of documents "floating in a sea of PPI::Token::Whitespace".
 
-Well it doesn't after the __END__ tag.
+Well not after the __END__ tag it doesn't.
 
-Once you __END__, it's all over. Anything after that tag isn't even fit
+Once you __END__ it's all over. Anything after that tag isn't even fit
 to be called whitespace. It just simply doesn't exist as far as perl
 (the interpreter) is concerned.
 
@@ -35,17 +35,19 @@ Basically, the completely worthless bits of the file :)
 
 =head1 METHODS
 
-This class has no method beyond what is provided by its L<PPI::Token> and
+This class has no method beyond what is provided by it's L<PPI::Token> and
 L<PPI::Element> parent classes.
 
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -55,17 +57,18 @@ our @ISA = "PPI::Token";
 # Tokenizer Methods
 
 ### XS -> PPI/XS.xs:_PPI_Token_End__significant 0.900+
-sub significant() { '' }
+sub significant { '' }
 
-sub __TOKENIZER__on_char() { 1 }
+sub __TOKENIZER__on_char { 1 }
 
 sub __TOKENIZER__on_line_start {
 	my $t = $_[1];
 
 	# Can we classify the entire line in one go
-	if ( $t->{line} =~ /^=(\w+)/ ) {
+	$_ = $t->{line};
+	if ( /^=(\w+)/ ) {
 		# A Pod tag... change to pod mode
-		$t->_new_token( 'Pod', $t->{line} );
+		$t->_new_token( 'Pod', $_ ) or return undef;
 		unless ( $1 eq 'cut' ) {
 			# Normal start to pod
 			$t->{class} = 'PPI::Token::Pod';
@@ -92,15 +95,15 @@ sub __TOKENIZER__on_line_start {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
