@@ -24,14 +24,18 @@ from multiple levels below to reference the loop directly.
 There are no additional methods beyond those provided by the parent
 L<PPI::Token> and L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -39,15 +43,15 @@ our @ISA = "PPI::Token";
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
