@@ -8,23 +8,22 @@ PPI::Token::Operator - Token class for operators
 
 =head1 INHERITANCE
 
-  PPI::Token::Operator
-  isa PPI::Token
-      isa PPI::Element
+  PPI::Token::Magic
+  isa PPI::Token::Symbol
+      isa PPI::Token
+          isa PPI::Element
 
 =head1 SYNOPSIS
 
   # This is the list of valid operators
   ++   --   **   !    ~    +    -
   =~   !~   *    /    %    x
-  <<   >>   lt   gt   le   ge   cmp  ~~
+  <<   >>   lt   gt   le   ge   cmp
   ==   !=   <=>  .    ..   ...  ,
   &    |    ^    &&   ||   //
-  ?    :    **=  +=   -=   .=   *=   /=
-  %=   x=   &=   |=   ^=   <<=  >>=  &&=
-  ||=  //=  <    >    <=   >=   <>   =>   ->
-  and  or   xor  not  eq   ne   <<>>
-
+  ?    :    =    +=   -=   *=   .=
+  <    >    <=   >=   <>   =>   ->
+  and  or   dor  not  eq   ne
 
 =head1 DESCRIPTION
 
@@ -37,15 +36,35 @@ object.
 There are no additional methods beyond those provided by the parent
 L<PPI::Token> and L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token ();
-use PPI::Singletons '%OPERATOR';
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION %OPERATOR};
+BEGIN {
+	$VERSION = '1.001';
 
-our @ISA = "PPI::Token";
+	# Build the operator index
+	### NOTE - This is accessed several times explicitly
+	###        in PPI::Token::Word. Do not rename this
+	###        without also correcting them.
+	%OPERATOR = map { $_ => 1 } (
+		qw{
+		-> ++ -- ** ! ~ + -
+		=~ !~ * / % x + - . << >>
+		< > <= >= lt gt le ge
+		== != <=> eq ne cmp
+		& | ^ && || // .. ...
+		? : = += -= *= .=
+		=> <>
+		and or dor not
+		}, ',' 	# Avoids "comma in qw{}" warning
+		);
+}
 
 
 
@@ -59,41 +78,23 @@ sub __TOKENIZER__on_char {
 	my $char = substr( $t->{line}, $t->{line_cursor}, 1 );
 
 	# Are we still an operator if we add the next character
-	my $content = $t->{token}->{content};
-	# special case for <<>> operator
-	if(length($content) < 4 &&
-		$content . substr( $t->{line}, $t->{line_cursor}, 4 - length($content) ) eq '<<>>') {
-		return 1;
-	}
-	return 1 if $OPERATOR{ $content . $char };
-
-	# Handle the special case of a .1234 decimal number
-	if ( $content eq '.' ) {
-		if ( $char =~ /^[0-9]$/ ) {
-			# This is a decimal number
-			$t->{class} = $t->{token}->set_class('Number::Float');
-			return $t->{class}->__TOKENIZER__on_char( $t );
-		}
-	}
+	return 1 if $OPERATOR{ $t->{token}->{content} . $char };
 
 	# Handle the special case if we might be a here-doc
-	if ( $content eq '<<' ) {
-		pos $t->{line} = $t->{line_cursor};
-		# Either <<FOO  or << 'FOO'  or <<\FOO  or
-		#        <<~FOO or <<~ 'FOO' or <<~\FOO
-		### Is the zero-width look-ahead assertion really
-		### supposed to be there?
-		if ( $t->{line} =~ m/\G ~? (?: (?!\d)\w | \s*['"`] | \\\w ) /gcx ) {
+	if ( $t->{token}->{content} eq '<<' ) {
+		my $line = substr( $t->{line}, $t->{line_cursor} );
+		if ( $line =~ /^(?:[^\W\d]|\s*['"`])/ ) {
 			# This is a here-doc.
 			# Change the class and move to the HereDoc's own __TOKENIZER__on_char method.
-			$t->{class} = $t->{token}->set_class('HereDoc');
+			$t->_set_token_class('HereDoc');
 			return $t->{class}->__TOKENIZER__on_char( $t );
 		}
 	}
 
 	# Handle the special case of the null Readline
-	$t->{class} = $t->{token}->set_class('QuoteLike::Readline')
-		if $content eq '<>' or $content eq '<<>>';
+	if ( $t->{token}->{content} eq '<>' ) {
+		$t->_set_token_class('QuoteLike::Readline');
+	}
 
 	# Finalize normally
 	$t->_finalize_token->__TOKENIZER__on_char( $t );
@@ -105,15 +106,15 @@ sub __TOKENIZER__on_char {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
