@@ -22,15 +22,18 @@ documentation within a Perl document.
 This class provides some additional methods beyond those provided by its
 L<PPI::Token> and L<PPI::Element> parent classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use Params::Util qw{_INSTANCE};
-use PPI::Token   ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -55,12 +58,12 @@ sub merge {
 	my $class = (! ref $_[0]) ? shift : return undef;
 
 	# Check there are no bad arguments
-	if ( grep { ! _INSTANCE($_, 'PPI::Token::Pod') } @_ ) {
+	if ( grep { ! isa( ref $_, 'PPI::Token::Pod' ) } @_ ) {
 		return undef;
 	}
 
 	# Get the tokens, and extract the lines
-	my @content = ( map { [ $_->lines ] } @_ ) or return undef;
+	my @content = (map { $_->lines } @_) or return undef;
 
 	# Remove the leading =pod tags, trailing =cut tags, and any empty lines
 	# between them and the pod contents.
@@ -97,9 +100,7 @@ returning them as a list.
 
 =cut
 
-sub lines {
-	split /(?:\015{1,2}\012|\015|\012)/, $_[0]->{content};
-}
+sub lines { split /(?:\015{1,2}\012|\015|\012)/, $_[0]->{content} }
 
 
 
@@ -110,7 +111,7 @@ sub lines {
 # PPI::Element Methods
 
 ### XS -> PPI/XS.xs:_PPI_Token_Pod__significant 0.900+
-sub significant() { '' }
+sub significant { '' }
 
 
 
@@ -128,7 +129,7 @@ sub __TOKENIZER__on_line_start {
 	# Check the line to see if it is a =cut line
 	if ( $t->{line} =~ /^=(\w+)/ ) {
 		# End of the token
-		$t->_finalize_token if $1 eq 'cut';
+		$t->_finalize_token if lc $1 eq 'cut';
 	}
 
 	0;
@@ -140,15 +141,15 @@ sub __TOKENIZER__on_line_start {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
