@@ -18,40 +18,37 @@ The C<PPI::Token::Quote> class is never instantiated, and simply
 provides a common abstract base class for the four quote classes.
 In PPI, a "quote" is limited to only the quote-like things that
 themselves directly represent a string. (although this includes
-double quotes with interpolated elements inside them, note that
-L<String::InterpolatedVariables> allows to extract them).
+double quotes with interpolated elements inside them).
 
 The subclasses of C<PPI::Token::Quote> are:
 
-=over 2
+C<''> - L<PPI::Token::Quote::Single>
 
-=item C<''> - L<PPI::Token::Quote::Single>
+C<q{}> - L<PPI::Token::Quote::Literal>
 
-=item C<q{}> - L<PPI::Token::Quote::Literal>
+C<""> - L<PPI::Token::Quote::Double>
 
-=item C<""> - L<PPI::Token::Quote::Double>
-
-=item C<qq{}> - L<PPI::Token::Quote::Interpolate>
-
-=back
+C<qq{}> - L<PPI::Token::Quote::Interpolate>
 
 The names are hopefully obvious enough not to have to explain what
 each class is here. See their respective pages for more details.
 
 Please note that although the here-doc B<does> represent a literal
 string, it is such a nasty piece of work that in L<PPI> it is given the
-honor of its own token class (L<PPI::Token::HereDoc>).
+honor of it's own token class (L<PPI::Token::HereDoc>).
 
 =head1 METHODS
 
 =cut
 
 use strict;
-use PPI::Token ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -81,35 +78,21 @@ of the quotes.
 #	die "$class does not implement method ->string";
 #}
 
-=pod
-
-=head2 literal
-
-The C<literal> method is provided by ::Quote::Literal and
-::Quote::Single.  This returns the value of the string as Perl sees
-it: without the quote marks and with C<\\> and C<\'> resolved to C<\>
-and C<'>.
-
-The C<literal> method is not implemented by ::Quote::Double or
-::Quote::Interpolate yet.
-
-=cut
-
 1;
 
 =pod
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
