@@ -27,19 +27,19 @@ There are several methods available for C<PPI::Token::Quote::Double>, beyond
 those provided by the parent L<PPI::Token::Quote>, L<PPI::Token> and
 L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use Params::Util                     qw{_INSTANCE};
-use PPI::Token::Quote                ();
-use PPI::Token::_QuoteEngine::Simple ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token::_QuoteEngine::Simple',
+         'PPI::Token::Quote';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = qw{
-	PPI::Token::_QuoteEngine::Simple
-	PPI::Token::Quote
-};
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -62,8 +62,10 @@ Returns true if the string contains interpolations, or false if not.
 # Upgrade: Return the interpolated substrings.
 # Upgrade: Returns parsed expressions.
 sub interpolations {
+	my $self = shift;
+
 	# Are there any unescaped $things in the string
-	!! ($_[0]->content =~ /(?<!\\)(?:\\\\)*[\$\@]/);
+	!! $self->content =~ /(?<!\\)(?:\\\\)*\$/;
 }
 
 =pod
@@ -73,29 +75,26 @@ sub interpolations {
 For various reasons, some people find themselves compelled to have
 their code in the simplest form possible.
 
-The C<simplify> method will, if possible, modify a simple double-quoted
-string token in place, turning it into the equivalent single-quoted
-string. If the token is modified, it is reblessed into the
-L<PPI::Token::Quote::Single> package.
+The C<simply> method will turn a simple double-quoted string into the
+equivalent single-quoted string.
 
-Because the length of the content is not changed, there is no need
-to call the document's C<flush_locations> method.
-
-The object itself is returned as a convenience.
+If the double can be simplified, it will be modified in place and
+returned as a convenience, or returns false if the string cannot be
+simplified.  
 
 =cut
 
 sub simplify {
 	# This only works on EXACTLY this class
-	my $self = _INSTANCE(shift, 'PPI::Token::Quote::Double') or return undef;
+	my $self = isa(ref $_[0], 'PPI::Token::Quote::Double') ? shift : return undef;
 
 	# Don't bother if there are characters that could complicate things
 	my $content = $self->content;
-	my $value   = substr($content, 1, length($content) - 2);
-	return $self if $value =~ /[\\\$@\'\"]/;
+	my $value   = substr($content, 1, length($content) - 1);
+	return '' if $value =~ /[\\\$\'\"]/;
 
 	# Change the token to a single string
-	$self->{content} = "'$value'";
+	$self->{content} = '"' . $value . '"';
 	bless $self, 'PPI::Token::Quote::Single';
 }
 
@@ -108,6 +107,20 @@ sub simplify {
 #####################################################################
 # PPI::Token::Quote Methods
 
+=pod
+
+=begin testing string 3
+
+my $Document = PPI::Document->new( \'print "foo";' );
+isa_ok( $Document, 'PPI::Document' );
+my $Double = $Document->find_first('Token::Quote::Double');
+isa_ok( $Double, 'PPI::Token::Quote::Double' );
+is( $Double->string, 'foo', '->string returns as expected' );
+
+=end testing
+
+=cut
+
 sub string {
 	my $str = $_[0]->{content};
 	substr( $str, 1, length($str) - 2 );
@@ -119,15 +132,15 @@ sub string {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
