@@ -24,18 +24,18 @@ There are no methods available for C<PPI::Token::Quote::Interpolate>
 beyond those provided by the parent L<PPI::Token::Quote>, L<PPI::Token> and
 L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token::Quote ();
-use PPI::Token::_QuoteEngine::Full ();
+use base 'PPI::Token::_QuoteEngine::Full',
+         'PPI::Token::Quote';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = qw{
-	PPI::Token::_QuoteEngine::Full
-	PPI::Token::Quote
-};
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -44,6 +44,25 @@ our @ISA = qw{
 #####################################################################
 # PPI::Token::Quote Methods
 
+=pod
+
+=begin testing string 8
+
+my $Document = PPI::Document->new( \"print qq{foo}, qq!bar!, qq <foo>;" );
+isa_ok( $Document, 'PPI::Document' );
+my $Interpolate = $Document->find('Token::Quote::Interpolate');
+is( scalar(@$Interpolate), 3, '->find returns three objects' );
+isa_ok( $Interpolate->[0], 'PPI::Token::Quote::Interpolate' );
+isa_ok( $Interpolate->[1], 'PPI::Token::Quote::Interpolate' );
+isa_ok( $Interpolate->[2], 'PPI::Token::Quote::Interpolate' );
+is( $Interpolate->[0]->string, 'foo', '->string returns as expected' );
+is( $Interpolate->[1]->string, 'bar', '->string returns as expected' );
+is( $Interpolate->[2]->string, 'foo', '->string returns as expected' );
+
+=end testing
+
+=cut
+
 sub string {
 	my $self     = shift;
 	my @sections = $self->_sections;
@@ -57,15 +76,15 @@ sub string {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
