@@ -30,18 +30,18 @@ There are no methods available for C<PPI::Token::Quote::Single> beyond
 those provided by the parent L<PPI::Token::Quote>, L<PPI::Token> and
 L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token::Quote ();
-use PPI::Token::_QuoteEngine::Simple ();
+use base 'PPI::Token::_QuoteEngine::Simple',
+         'PPI::Token::Quote';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = qw{
-	PPI::Token::_QuoteEngine::Simple
-	PPI::Token::Quote
-};
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -50,39 +50,40 @@ our @ISA = qw{
 #####################################################################
 # PPI::Token::Quote Methods
 
+=pod
+
+=begin testing string 3
+
+my $Document = PPI::Document->new( \"print 'foo';" );
+isa_ok( $Document, 'PPI::Document' );
+my $Single = $Document->find_first('Token::Quote::Single');
+isa_ok( $Single, 'PPI::Token::Quote::Single' );
+is( $Single->string, 'foo', '->string returns as expected' );
+
+=end testing
+
+=cut
+
 sub string {
 	my $str = $_[0]->{content};
 	substr( $str, 1, length($str) - 2 );
 }
 
-
-my %UNESCAPE = (
-	"\\'"  => "'",
-	"\\\\" => "\\",
-);
-
-sub literal {
-	# Unescape \\ and \' ONLY
-	my $str = $_[0]->string;
-	$str =~ s/(\\.)/$UNESCAPE{$1} || $1/ge;
-	return $str;
-}
-
 1;
 
 =pod
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
