@@ -21,19 +21,15 @@ exclude the string quotes and regular expressions.
 
 The subclasses of C<PPI::Token::QuoteLike> are:
 
-=over 2
+qw{} - L<PPI::Token::QuoteLike::Words>
 
-=item qw{} - L<PPI::Token::QuoteLike::Words>
+`` - L<PPI::Token::QuoteLike::Backtick>
 
-=item `` - L<PPI::Token::QuoteLike::Backtick>
+qx{} - L<PPI::Token::QuoteLike::Command>
 
-=item qx{} - L<PPI::Token::QuoteLike::Command>
+qr// - L<PPI::Token::QuoteLike::Regexp>
 
-=item qr// - L<PPI::Token::QuoteLike::Regexp>
-
-=item <FOO> - L<PPI::Token::QuoteLike::Readline>
-
-=back
+<FOO> - L<PPI::Token::QuoteLike::Readline>
 
 The names are hopefully obvious enough not to have to explain what
 each class is. See their pages for more details.
@@ -46,11 +42,12 @@ PPI's quote engine.
 =cut
 
 use strict;
-use PPI::Token ();
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -58,15 +55,15 @@ our @ISA = "PPI::Token";
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
