@@ -22,7 +22,7 @@ PPI::Token::Regexp::Transliterate - A transliteration regular expression token
 A C<PPI::Token::Regexp::Transliterate> object represents a single
 transliteration regular expression.
 
-I'm afraid you'll have to excuse the ridiculously long class name, but
+I'm afraid you'll have to excuse the rediculously long class name, but
 when push came to shove I ended up going for pedantically correct
 names for things (practically cut and paste from the various docs).
 
@@ -32,18 +32,19 @@ There are no methods available for C<PPI::Token::Regexp::Transliterate>
 beyond those provided by the parent L<PPI::Token::Regexp>, L<PPI::Token>
 and L<PPI::Element> classes.
 
+Got any ideas for methods? Submit a report to rt.cpan.org!
+
 =cut
 
 use strict;
-use PPI::Token::Regexp             ();
-use PPI::Token::_QuoteEngine::Full ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token::_QuoteEngine::Full',
+         'PPI::Token::Regexp';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = qw{
-	PPI::Token::_QuoteEngine::Full
-	PPI::Token::Regexp
-};
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 1;
 
@@ -51,15 +52,15 @@ our @ISA = qw{
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
