@@ -8,7 +8,7 @@ PPI::Token::Symbol - A token class for variables and other symbols
 
 =head1 INHERITANCE
 
-  PPI::Token::Symbol
+  PPI::Token::Word
   isa PPI::Token
       isa PPI::Element
 
@@ -22,18 +22,19 @@ variables and other things that start with a sigil.
 This class has several methods beyond what is provided by its
 L<PPI::Token> and L<PPI::Element> parent classes.
 
-Most methods are provided to help work out what the object is actually
-pointing at, rather than what it might appear to be pointing at.
+Most are provided to help work out what the object is actually pointing at,
+rather than what it might appear to be pointing at.
 
 =cut
  
 use strict;
-use Params::Util qw{_INSTANCE};
-use PPI::Token   ();
+use UNIVERSAL 'isa';
+use base 'PPI::Token';
 
-our $VERSION = '1.28401'; # TRIAL
-
-our @ISA = "PPI::Token";
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -59,8 +60,8 @@ variations.
 sub canonical {
 	my $symbol = shift->content;
 	$symbol =~ s/\s+//;
-	$symbol =~ s/\'/::/g;
 	$symbol =~ s/(?<=[\$\@\%\&\*])::/main::/;
+	$symbol =~ s/\'/::/g;
 	$symbol;
 }
 
@@ -70,7 +71,7 @@ sub canonical {
 
 The C<symbol> method returns the ACTUAL symbol this token refers to.
 
-A token of C<$foo> might actually be referring to C<@foo>, if it is found
+A token of C<$foo> might actually be refering to C<@foo>, if it is found
 in the form C<$foo[1]>.
 
 This method attempts to resolve these issues to determine the actual
@@ -80,40 +81,28 @@ Returns the symbol as a string.
 
 =cut
 
-my %cast_which_trumps_braces = map { $_ => 1 } qw{ $ @ % };
-
 sub symbol {
 	my $self   = shift;
 	my $symbol = $self->canonical;
 
 	# Immediately return the cases where it can't be anything else
 	my $type = substr( $symbol, 0, 1 );
+	return $symbol if $type eq '%';
 	return $symbol if $type eq '&';
 
 	# Unless the next significant Element is a structure, it's correct.
 	my $after  = $self->snext_sibling;
-	return $symbol unless _INSTANCE($after, 'PPI::Structure');
+	return $symbol unless isa( $after, 'PPI::Structure' );
 
-	# Process the rest for cases where it might actually be something else
+	# Process the rest for cases where it might actually be somethign else
 	my $braces = $after->braces;
 	return $symbol unless defined $braces;
 	if ( $type eq '$' ) {
-
-		# If it is cast to '$' or '@', that trumps any braces
-		my $before = $self->sprevious_sibling;
-		return $symbol if $before &&
-			$before->isa( 'PPI::Token::Cast' ) &&
-			$cast_which_trumps_braces{ $before->content };
-
-		# Otherwise the braces rule
-		substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
-		substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
+		return substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
+		return substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
 
 	} elsif ( $type eq '@' ) {
-		substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
-
-	} elsif ( $type eq '%' ) {
-		substr( $symbol, 0, 1, '@' ) if $braces eq '[]';
+		return substr( $symbol, 0, 1, '%' ) if $braces eq '{}';
 
 	}
 
@@ -124,30 +113,32 @@ sub symbol {
 
 =head2 raw_type
 
-The C<raw_type> method returns the B<apparent> type of the symbol in the
-form of its sigil.
+The C<raw_type> method returns the apparent type of the symbol in the
+form of it's sigil.
 
 Returns the sigil as a string.
 
 =cut
 
 sub raw_type {
-	substr( $_[0]->content, 0, 1 );
+	my $self = shift;
+	substr( $self->content, 0, 1 );
 }
 
 =pod
 
 =head2 symbol_type
 
-The C<symbol_type> method returns the B<actual> type of the symbol in the
-form of its sigil.
+The C<symbol_type> method returns the actual type of the symbol in the
+form of it's sigil.
 
 Returns the sigil as a string.
 
 =cut
 
 sub symbol_type {
-	substr( $_[0]->symbol, 0, 1 );
+	my $self = shift;
+	substr( $self->symbol, 0, 1 );
 }
 
 
@@ -161,59 +152,40 @@ sub __TOKENIZER__on_char {
 	my $t = $_[1];
 
 	# Suck in till the end of the symbol
-	pos $t->{line} = $t->{line_cursor};
-	if ( $t->{line} =~ m/\G([\w:\']+)/gc ) {
+	my $line = substr( $t->{line}, $t->{line_cursor} );
+	if ( $line =~ /^([\w:']+)/ ) {
 		$t->{token}->{content} .= $1;
-		$t->{line_cursor}      += length $1;
+		$t->{line_cursor} += length $1;
 	}
 
 	# Handle magic things
 	my $content = $t->{token}->{content};	
 	if ( $content eq '@_' or $content eq '$_' ) {
-		$t->{class} = $t->{token}->set_class( 'Magic' );
+		$t->_set_token_class( 'Magic' );
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
-	# Shortcut for most of the X:: symbols
+	# Shortcut for a couple of things
+	if ( $content eq '%::' ) {
+		return $t->_finalize_token->__TOKENIZER__on_char( $t );
+	}
 	if ( $content eq '$::' ) {
 		# May well be an alternate form of a Magic
 		my $nextchar = substr( $t->{line}, $t->{line_cursor}, 1 );
 		if ( $nextchar eq '|' ) {
 			$t->{token}->{content} .= $nextchar;
 			$t->{line_cursor}++;
-			$t->{class} = $t->{token}->set_class( 'Magic' );
+			$t->_set_token_class( 'Magic' );
 		}
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
-	if ( $content =~ /^[\$%*@&]::(?:[^\w]|$)/ ) {
-		my $current = substr( $content, 0, 3, '' );
-		$t->{token}->{content} = $current;
-		$t->{line_cursor} -= length( $content );
-		return $t->_finalize_token->__TOKENIZER__on_char( $t );
-	}
 	if ( $content =~ /^(?:\$|\@)\d+/ ) {
-		$t->{class} = $t->{token}->set_class( 'Magic' );
+		$t->_set_token_class( 'Magic' );
 		return $t->_finalize_token->__TOKENIZER__on_char( $t );
 	}
 
-	# Verify and extract actual full symbol name from sigil to end
-	my $sep = qr/ (?: :: | '(?!\d) ) /x; # :: and ' are namespace separators
-	my $pattern = qr/
-	^(
-		[\$@%&*]
-		(?:
-				: (?! : )			# allow single-colon non-magic variables
-			|
-				$sep?				# optional separator
-				\w+					# a word
-				(?: $sep \w+ )* 	# optionally more separator+word pairs
-				(?: ::		 )?		# optionally what's technically a
-									# compiler-magic hash, but keep it here
-		)
-	)
-	/x;
-	return undef if $content !~ $pattern;
-
+	# Trim off anything we oversucked...
+	$content =~ /^((?:\$|\@|\%|\&|\*)(?:\'|\::)?[^\W\d]\w*(?:(?:\'|\::)[^\W\d]\w*)*(?:::)?)/ or return undef;
 	unless ( length $1 eq length $content ) {
 		$t->{line_cursor} += length($1) - length($content);
 		$t->{token}->{content} = $1;
@@ -228,15 +200,15 @@ sub __TOKENIZER__on_char {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
