@@ -9,7 +9,7 @@ PPI::Token::_QuoteEngine - The PPI Quote Engine
 =head1 DESCRIPTION
 
 The C<PPI::Token::_QuoteEngine> package is designed hold functionality
-for processing quotes and quote like operators, including regexes.
+for processing quotes and quote like operators, including regex's.
 These have special requirements in parsing.
 
 The C<PPI::Token::_QuoteEngine> package itself provides various parsing
@@ -33,7 +33,10 @@ If -E<gt>fill returns true, finalise the token.
 use strict;
 use Carp ();
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
 
 
 
@@ -48,8 +51,6 @@ sub __TOKENIZER__on_char {
 	my $rv = $t->{token}->_fill( $t );
 	return undef unless defined $rv;
 
-	## Doesn't support "end of file" indicator
-
 	# Finalize the token and return 0 to tell the tokenizer
 	# to go to the next character.
 	$t->_finalize_token;
@@ -66,11 +67,44 @@ sub __TOKENIZER__on_char {
 # and quote like stuff, and accessible to the child classes
 
 # An outright scan, raw and fast.
-# Searches for a particular character, not escaped, loading in new
+# Searches for a particular character, loading in new
 # lines as needed.
 # When called, we start at the current position.
 # When leaving, the position should be set to the position
 # of the character, NOT the one after it.
+sub _scan_for_character {
+	my $class = shift;
+	my $t     = shift;
+	my $char  = (length $_[0] == 1) ? quotemeta shift : return undef;
+
+	# Create the search regex
+	my $search = qr/^(.*?$char)/;
+
+	my $string = '';
+	while ( exists $t->{line} ) {
+		# Get the search area for the current line
+		$_ = $t->{line_cursor}
+			? substr( $t->{line}, $t->{line_cursor} )
+			: $t->{line};
+
+		# Can we find a match on this line
+		if ( /$search/ ) {
+			# Found the character on this line
+			$t->{line_cursor} += length($1) - 1;
+			return $string . $1;
+		}
+
+		# Load in the next line
+		$string .= $_;
+		return undef unless defined $t->_fill_line;
+		$t->{line_cursor} = 0;
+	}
+
+	# Returning the string as a reference indicates EOF
+	\$string;
+}
+
+# Scan for a character, but not if it is escaped
 sub _scan_for_unescaped_character {
 	my $class = shift;
 	my $t     = shift;
@@ -78,37 +112,30 @@ sub _scan_for_unescaped_character {
 
 	# Create the search regex.
 	# Same as above but with a negative look-behind assertion.
-	my $search = qr/(.*?(?<!\\)(?:\\\\)*$char)/;
+	my $search = qr/^(.*?(?<!\\)(?:\\\\)*$char)/;
 
 	my $string = '';
 	while ( exists $t->{line} ) {
 		# Get the search area for the current line
-		pos $t->{line} = $t->{line_cursor};
+		$_ = $t->{line_cursor}
+			? substr( $t->{line}, $t->{line_cursor} )
+			: $t->{line};
 
 		# Can we find a match on this line
-		if ( $t->{line} =~ m/\G$search/gc ) {
+		if ( /$search/ ) {
 			# Found the character on this line
 			$t->{line_cursor} += length($1) - 1;
 			return $string . $1;
 		}
 
 		# Load in the next line
-		$string .= substr $t->{line}, $t->{line_cursor};
-		my $rv = $t->_fill_line('inscan');
-		if ( $rv ) {
-			# Push to first character
-			$t->{line_cursor} = 0;
-		} elsif ( defined $rv ) {
-			# We hit the End of File
-			return \$string;
-		} else {
-			# Unexpected error
-			return undef;
-		}
+		$string .= $_;
+		return undef unless defined $t->_fill_line;
+		$t->{line_cursor} = 0;
 	}
 
-	# We shouldn't be able to get here
-	return undef;
+	# Returning the string as a reference indicates EOF
+	\$string;
 }
 
 # Scan for a close braced, and take into account both escaping,
@@ -124,39 +151,31 @@ sub _scan_for_brace_character {
 	# Create the search string
 	$close_brace = quotemeta $close_brace;
 	$open_brace = quotemeta $open_brace;
-	my $search = qr/\G(.*?(?<!\\)(?:\\\\)*(?:$open_brace|$close_brace))/;
+	my $search = qr/^(.*?(?<!\\)(?:\\\\)*(?:$open_brace|$close_brace))/;
 
 	# Loop as long as we can get new lines
 	my $string = '';
 	my $depth = 1;
 	while ( exists $t->{line} ) {
 		# Get the search area
-		pos $t->{line} = $t->{line_cursor};
+		$_ = $t->{line_cursor}
+			? substr( $t->{line}, $t->{line_cursor} )
+			: $t->{line};
 
 		# Look for a match
-		unless ( $t->{line} =~ /$search/gc ) {
+		unless ( /$search/ ) {
 			# Load in the next line
-			$string .= substr( $t->{line}, $t->{line_cursor} );
-			my $rv = $t->_fill_line('inscan');
-			if ( $rv ) {
-				# Push to first character
-				$t->{line_cursor} = 0;
-				next;
-			}
-			if ( defined $rv ) {
-				# We hit the End of File
-				return \$string;
-			}
-
-			# Unexpected error
-			return undef;
+			$string .= $_;
+			defined $t->_fill_line or return undef;
+			$t->{line_cursor} = 0;
+			next;
 		}
 
 		# Add to the string
 		$string .= $1;
 		$t->{line_cursor} += length $1;
 
-		# Alter the depth and continue if we aren't at the end
+		# Alter the depth and continue if we arn't at the end
 		$depth += ($1 =~ /$open_brace$/) ? 1 : -1 and next;
 
 		# Rewind the cursor by one character ( cludgy hack )
@@ -179,16 +198,18 @@ sub _scan_quote_like_operator_gap {
 	my $string = '';
 	while ( exists $t->{line} ) {
 		# Get the search area for the current line
-		pos $t->{line} = $t->{line_cursor};
+		$_ = $t->{line_cursor}
+			? substr( $t->{line}, $t->{line_cursor} )
+			: $t->{line};
 
 		# Since this regex can match zero characters, it should always match
-		$t->{line} =~ /\G(\s*(?:\#.*)?)/gc or return undef;
+		/^(\s*(?:\#.*)?)/s or return undef;
 
 		# Add the chars found to the string
 		$string .= $1;
 
 		# Did we match the entire line?
-		unless ( $t->{line_cursor} + length $1 == length $t->{line} ) {
+		unless ( length $1 == length $_ ) {
 			# Partial line match, which means we are at
 			# the end of the gap. Fix the cursor and return
 			# the string.
@@ -199,20 +220,14 @@ sub _scan_quote_like_operator_gap {
 		# Load in the next line.
 		# If we reach the EOF, $t->{line} gets deleted,
 		# which is caught by the while.
-		my $rv = $t->_fill_line('inscan');
-		if ( $rv ) {
-			# Set the cursor to the first character
-			$t->{line_cursor} = 0;
-		} elsif ( defined $rv ) {
-			# Returning the string as a reference indicates EOF
-			return \$string;
-		} else {
-			return undef;
-		}
+		return undef unless defined $t->_fill_line;
+	
+		# Set the cursor to the first character
+		$t->{line_cursor} = 0;
 	}
 
-	# Shouldn't be able to get here
-	return undef;
+	# Returning the string as a reference indicates EOF
+	\$string;
 }
 
 1;
@@ -221,15 +236,15 @@ sub _scan_quote_like_operator_gap {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
