@@ -3,22 +3,27 @@ package PPI::Token::_QuoteEngine::Simple;
 # Simple quote engine
 
 use strict;
-use PPI::Token::_QuoteEngine ();
+use base 'PPI::Token::_QuoteEngine';
+
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.001';
+}
+
+
 
-our $VERSION = '1.28401'; # TRIAL
 
-our @ISA = 'PPI::Token::_QuoteEngine';
 
 sub new {
 	my $class     = shift;
-	my $separator = shift or return undef;
+	my $seperator = shift or return undef;
 
-	# Create a new token containing the separator
+	# Create a new token containing the seperator
 	### This manual SUPER'ing ONLY works because none of
 	### Token::Quote, Token::QuoteLike and Token::Regexp
 	### implement a new function of their own.
-	my $self = PPI::Token::new( $class, $separator ) or return undef;
-	$self->{separator} = $separator;
+	my $self = PPI::Token::new( $class, $seperator ) or return undef;
+	$self->{seperator} = $seperator;
 
 	$self;
 }
@@ -28,8 +33,8 @@ sub _fill {
 	my $t     = shift;
 	my $self  = $t->{token} or return undef;
 
-	# Scan for the end separator
-	my $string = $self->_scan_for_unescaped_character( $t, $self->{separator} );
+	# Scan for the end seperator
+	my $string = $self->_scan_for_unescaped_character( $t, $self->{seperator} );
 	return undef unless defined $string;
 	if ( ref $string ) {
 		# End of file
@@ -48,15 +53,15 @@ sub _fill {
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
