@@ -10,8 +10,8 @@ PPI::Tokenizer - The Perl Document Tokenizer
 
   # Create a tokenizer for a file, array or string
   $Tokenizer = PPI::Tokenizer->new( 'filename.pl' );
-  $Tokenizer = PPI::Tokenizer->new( \@lines       );
-  $Tokenizer = PPI::Tokenizer->new( \$source      );
+  $Tokenizer = PPI::Tokenizer->new( \@lines        );
+  $Tokenizer = PPI::Tokenizer->new( \$source       );
   
   # Return all the tokens for the document
   my $tokens = $Tokenizer->all_tokens;
@@ -35,38 +35,29 @@ By the time you are reading this, you probably need to know a little
 about the difference between how perl parses Perl "code" and how PPI
 parsers Perl "documents".
 
-"perl" itself (the interpreter) uses a heavily modified lex specification
-to specify its parsing logic, maintains several types of state as it
-goes, and incrementally tokenizes, lexes AND EXECUTES at the same time.
-
-In fact, it is provably impossible to use perl's parsing method without
-simultaneously executing code. A formal mathematical proof has been
-published demonstrating the method.
+"perl" itself (the intepreter) uses a heavily modified lex specification
+to specify it's parsing logic, maintains several types of state as it
+goes, and both tokenises and lexes AND EXECUTES at the same time.
+In fact, it's provably impossible to use perl's parsing method without
+BEING perl.
 
 This is where the truism "Only perl can parse Perl" comes from.
 
-PPI uses a completely different approach by abandoning the (impossible)
-ability to parse Perl the same way that the interpreter does, and instead
-parsing the source as a document, using a document structure independently
-derived from the Perl documentation and approximating the perl interpreter
-interpretation as closely as possible.
+PPI uses a completely different approach by abandoning the ability to
+provably parse perl, and instead to parse the source as a document, but
+get so close to being perfect that unless you do insanely silly things,
+it can handle it.
 
 It was touch and go for a long time whether we could get it close enough,
 but in the end it turned out that it could be done.
 
-In this approach, the tokenizer C<PPI::Tokenizer> is implemented separately
-from the lexer L<PPI::Lexer>.
+In this approach, the tokenizer C<PPI::Tokenizer> is seperate from the
+lexer L<PPI::Lexer>. The job of C<PPI::Tokenizer> is to take pure source
+as a string and break it up into a stream/set of tokens.
 
-The job of C<PPI::Tokenizer> is to take pure source as a string and break it
-up into a stream/set of tokens, and contains most of the "black magic" used
-in PPI. By comparison, the lexer implements a relatively straight forward
-tree structure, and has an implementation that is uncomplicated (compared
-to the insanity in the tokenizer at least).
-
-The Tokenizer uses an immense amount of heuristics, guessing and cruft,
-supported by a very B<VERY> flexible internal API, but fortunately it was
-possible to largely encapsulate the black magic, so there is not a lot that
-gets exposed to people using the C<PPI::Tokenizer> itself.
+The Tokenizer uses a hell of a lot of heuristics, guessing, and cruft,
+supported by a very B<VERY> flexible internal API, but fortunately there's
+not a lot that gets exposed to people using the C<PPI::Tokenizer> itself.
 
 =head1 METHODS
 
@@ -76,59 +67,21 @@ in private methods.
 
 =cut
 
-# Make sure everything we need is loaded so
-# we don't have to go and load all of PPI.
+# Make sure everything we need is loaded, so we
+# don't have to go and load all of PPI.
 use strict;
-use Params::Util    qw{_INSTANCE _SCALAR0 _ARRAY0};
-use List::Util 1.33 ();
-use PPI::Util       ();
+use UNIVERSAL 'isa';
+use List::MoreUtils ();
 use PPI::Element    ();
 use PPI::Token      ();
-use PPI::Exception  ();
-use PPI::Exception::ParserRejection ();
-use PPI::Document ();
 
-our $VERSION = '1.28401'; # TRIAL
+use vars qw{$VERSION $errstr};
+BEGIN {
+	$VERSION = '1.001';
+	$errstr  = '';
+}
 
-# The x operator cannot follow most Perl operators, implying that
-# anything beginning with x following an operator is a word.
-# These are the exceptions.
-my %X_CAN_FOLLOW_OPERATOR = map { $_ => 1 } qw( -- ++ );
 
-# The x operator cannot follow most structure elements, implying that
-# anything beginning with x following a structure element is a word.
-# These are the exceptions.
-my %X_CAN_FOLLOW_STRUCTURE = map { $_ => 1 } qw( } ] \) );
-
-# Something that looks like the x operator but follows a word
-# is usually that word's argument.
-# These are the exceptions.
-# chop, chomp, dump are ambiguous because they can have either parms
-# or no parms.
-my %X_CAN_FOLLOW_WORD = map { $_ => 1 } qw(
-		endgrent
-		endhostent
-		endnetent
-		endprotoent
-		endpwent
-		endservent
-		fork
-		getgrent
-		gethostent
-		getlogin
-		getnetent
-		getppid
-		getprotoent
-		getpwent
-		getservent
-		setgrent
-		setpwent
-		time
-		times
-		wait
-		wantarray
-		__SUB__
-);
 
 
 
@@ -137,7 +90,7 @@ my %X_CAN_FOLLOW_WORD = map { $_ => 1 } qw(
 
 =pod
 
-=head2 new $file | \@lines | \$source
+=head2 new $source | \@lines | \$source
 
 The main C<new> constructor creates a new Tokenizer object. These
 objects have no configuration parameters, and can only be used once,
@@ -147,78 +100,69 @@ It takes as argument either a normal scalar containing source code,
 a reference to a scalar containing source code, or a reference to an
 ARRAY containing newline-terminated lines of source code.
 
-Returns a new C<PPI::Tokenizer> object on success, or throws a
-L<PPI::Exception> exception on error.
+Returns a new C<PPI::Tokenizer> object on success, or C<undef> on error.
 
 =cut
 
 sub new {
-	my $class = ref($_[0]) || $_[0];
+	my $class = (ref $_[0] ? ref shift : shift)->_clear;
 
 	# Create the empty tokenizer struct
 	my $self = bless {
 		# Source code
-		source       => undef,
-		source_bytes => undef,
-		document     => undef,
+		source         => undef,
+		source_bytes   => undef,
 
 		# Line buffer
-		line         => undef,
-		line_length  => undef,
-		line_cursor  => undef,
-		line_count   => 0,
+		line           => undef,
+		line_length    => undef,
+		line_cursor    => undef,
+		line_count     => 0,
 
 		# Parse state
-		token        => undef,
-		class        => 'PPI::Token::BOM',
-		zone         => 'PPI::Token::Whitespace',
-		features     => undef,
+		token          => undef,
+		class          => 'PPI::Token::Whitespace',
+		zone           => 'PPI::Token::Whitespace',
 
 		# Output token buffer
-		tokens       => [],
-		token_cursor => 0,
-		token_eof    => 0,
+		tokens         => [],
+		token_cursor   => 0,
+		token_eof      => 0,
+		}, $class;
 
-		# Perl 6 blocks
-		perl6        => [],
-	}, $class;
-
-	if ( ! defined $_[1] ) {
+	if ( ! defined $_[0] ) {
 		# We weren't given anything
-		PPI::Exception->throw("No source provided to Tokenizer");
+		return $self->_error( "No source provided to Tokenizer" );
 
-	} elsif ( ! ref $_[1] ) {
-		my $source = PPI::Util::_slurp($_[1]);
-		if ( ref $source ) {
-			# Content returned by reference
-			$self->{source} = $$source;
-		} else {
-			# Errors returned as a string
-			return( $source );
-		}
+	} elsif ( ! ref $_[0] ) {
+		local $/ = undef;
+		open( PPIINPUT, '<', $_[0] ) or return("open($_[0]) failed: $!");
+		$self->{source} = <PPIINPUT>;
+		close( PPIINPUT ) or return("close($_[0]) failed: $!");
 
-	} elsif ( _SCALAR0($_[1]) ) {
-		$self->{source} = ${$_[1]};
+	} elsif ( isa($_[0], 'SCALAR') ) {
+		$self->{source} = ${shift()};
 
-	} elsif ( _ARRAY0($_[1]) ) {
-		$self->{source} = join '', map { "\n" } @{$_[1]};
+	} elsif ( isa($_[0], 'ARRAY') ) {
+		$self->{source} = join "\n", @{shift()};
 
 	} else {
 		# We don't support whatever this is
-		PPI::Exception->throw(ref($_[1]) . " is not supported as a source provider");
+		return $self->_error( ref($_[0]) . " is not supported as a source provider" );
 	}
 
+	# Localise newlines
+	$self->{source} =~ s/(?:\015{1,2}\012|\015|\012)/\n/g;
+
 	# We can't handle a null string
 	$self->{source_bytes} = length $self->{source};
-	if ( $self->{source_bytes} ) {
-		# Split on local newlines
-		$self->{source} =~ s/(?:\015{1,2}\012|\015|\012)/\n/g;
-		$self->{source} = [ split /(?<=\n)/, $self->{source} ];
-
-	} else {
-		$self->{source} = [ ];
+	unless ( $self->{source_bytes} ) {
+		return $self->_error( "Nothing to parse" );
 	}
 
+	# Split into the line array
+	$self->{source} = [ split /(?<=\n)/, $self->{source} ];
+
 	### EVIL
 	# I'm explaining this earlier than I should so you can understand
 	# why I'm about to do something that looks very strange. There's
@@ -237,9 +181,7 @@ sub new {
 	# once the tokenizer hits end of file, it examines the last token to
 	# manually either remove the ' ' token, or chop it off the end of
 	# a longer one in which the space would be valid.
-	if ( List::Util::any { /^__(?:DATA|END)__\s*$/ } @{$self->{source}} ) {
-		$self->{source_eof_chop} = '';
-	} elsif ( ! defined $self->{source}->[0] ) {
+	if ( List::MoreUtils::any { /^__(?:DATA|END)__\s*$/ } @{$self->{source}} ) {
 		$self->{source_eof_chop} = '';
 	} elsif ( $self->{source}->[-1] =~ /\s$/ ) {
 		$self->{source_eof_chop} = '';
@@ -251,11 +193,6 @@ sub new {
 	$self;
 }
 
-sub _document {
-	my $self = shift;
-	return @_ ? $self->{document} = shift : $self->{document};
-}
-
 
 
 
@@ -297,44 +234,26 @@ sub get_token {
 	}
 
 	# Return the next token if we can
-	if ( my $token = $self->{tokens}->[ $self->{token_cursor} ] ) {
+	if ( $_ = $self->{tokens}->[ $self->{token_cursor} ] ) {
 		$self->{token_cursor}++;
-		return $token;
+		return $_;
 	}
 
-	my $line_rv;
-
-	# Catch exceptions and return undef, so that we
-	# can start to convert code to exception-based code.
-	my $rv = eval {
-		# No token, we need to get some more
-		while ( $line_rv = $self->_process_next_line ) {
-			# If there is something in the buffer, return it
-			# The defined() prevents a ton of calls to PPI::Util::TRUE
-			if ( defined( my $token = $self->{tokens}->[ $self->{token_cursor} ] ) ) {
-				$self->{token_cursor}++;
-				return $token;
-			}
-		}
-		return undef;
-	};
-	if ( $@ ) {
-		if ( _INSTANCE($@, 'PPI::Exception') ) {
-			$@->throw;
-		} else {
-			my $errstr = $@;
-			$errstr =~ s/^(.*) at line .+$/$1/;
-			PPI::Exception->throw( $errstr );
-		}
-	} elsif ( $rv ) {
-		return $rv;
-	}
-
-	if ( defined $line_rv ) {
-		# End of file, but we can still return things from the buffer
-		if ( my $token = $self->{tokens}->[ $self->{token_cursor} ] ) {
+	# No token, we need to get some more
+	while ( $_ = $self->_process_next_line ) {
+		# If there is something in the buffer, return it
+		if ( $_ = $self->{tokens}->[ $self->{token_cursor} ] ) {
 			$self->{token_cursor}++;
-			return $token;
+			return $_;
+		}
+	}
+
+
+	if ( defined $_ ) {
+		# End of file, but we can still return things from the buffer
+		if ( $_ = $self->{tokens}->[ $self->{token_cursor} ] ) {
+			$self->{token_cursor}++;
+			return $_;
 		}
 
 		# Set our token end of file flag
@@ -350,7 +269,7 @@ sub get_token {
 
 =head2 all_tokens
 
-When not being used as an iterator, the C<all_tokens> method tells
+When noy being used as an iterator, the C<all_tokens> method tells
 the Tokenizer to parse the entire file and return all of the tokens
 in a single ARRAY reference.
 
@@ -358,45 +277,34 @@ It should be noted that C<all_tokens> does B<NOT> interfere with the
 use of the Tokenizer object as an iterator (does not modify the token
 cursor) and use of the two different mechanisms can be mixed safely.
 
-Returns a reference to an ARRAY of L<PPI::Token> objects on success
-or throws an exception on error.
+Returns a reference to an ARRAY of L<PPI::Token> objects on success,
+C<0> in the special case that the file/string contains NO tokens at
+all, or C<undef> on error.
 
 =cut
 
 sub all_tokens {
 	my $self = shift;
 
-	# Catch exceptions and return undef, so that we
-	# can start to convert code to exception-based code.
-	my $ok = eval {
-		# Process lines until we get EOF
-		unless ( $self->{token_eof} ) {
-			my $rv;
-			while ( $rv = $self->_process_next_line ) {}
-			unless ( defined $rv ) {
-				PPI::Exception->throw("Error while processing source");
-			}
+	# Process lines until we get EOF
+	unless ( $self->{token_eof} ) {
+		my $rv;
+		while ( $rv = $self->_process_next_line ) {}
+		return $self->_error( "Error while processing source" ) unless defined $rv;
 
-			# Clean up the end of the tokenizer
-			$self->_clean_eof;
-		}
-		1;
-	};
-	if ( !$ok ) {
-		my $errstr = $@;
-		$errstr =~ s/^(.*) at line .+$/$1/;
-		PPI::Exception->throw( $errstr );
+		# Clean up the end of the tokenizer
+		$self->_clean_eof;
 	}
 
 	# End of file, return a copy of the token array.
-	return [ @{$self->{tokens}} ];
+	@{ $self->{tokens} } ? [ @{$self->{tokens}} ] : 0;
 }
 
 =pod
 
 =head2 increment_cursor
 
-Although exposed as a public method, C<increment_cursor> is implemented
+Although exposed as a public method, C<increment_method> is implemented
 for expert use only, when writing lexers or other components that work
 directly on token streams.
 
@@ -418,7 +326,7 @@ sub increment_cursor {
 
 =head2 decrement_cursor
 
-Although exposed as a public method, C<decrement_cursor> is implemented
+Although exposed as a public method, C<decrement_method> is implemented
 for expert use only, when writing lexers or other components that work
 directly on token streams.
 
@@ -453,7 +361,7 @@ sub decrement_cursor {
 
 # Fetches the next line from the input line buffer
 # Returns undef at EOF.
-sub _get_line {
+ sub _get_line {
 	my $self = shift;
 	return undef unless $self->{source}; # EOF hit previously
 
@@ -464,30 +372,23 @@ sub _get_line {
 	$self->{source} = undef unless defined $line;
 
 	# Return the line (or EOF flag)
-	return $line; # string or undef
+	$line; # string or undef
 }
 
 # Fetches the next line, ready to process
 # Returns 1 on success
 # Returns 0 on EOF
+# Returns undef on error
 sub _fill_line {
-	my $self   = shift;
-	my $inscan = shift;
+	my $self = shift;
 
 	# Get the next line
 	my $line = $self->_get_line;
 	unless ( defined $line ) {
-		# End of file
-		unless ( $inscan ) {
-			delete $self->{line};
-			delete $self->{line_cursor};
-			delete $self->{line_length};
-			return 0;
-		}
-
-		# In the scan version, just set the cursor to the end
-		# of the line, and the rest should just cascade out.
-		$self->{line_cursor} = $self->{line_length};
+		# End of file, clean up
+		delete $self->{line};
+		delete $self->{line_cursor};
+		delete $self->{line_length};
 		return 0;
 	}
 
@@ -537,29 +438,126 @@ sub _process_next_line {
 		if ( ref $self->{source} eq 'ARRAY' and ! @{$self->{source}} ) {
 			$self->_clean_eof;
 		}
-
-		# Defined but false means next line
-		return 1 if defined $rv;
-		PPI::Exception->throw("Error at line $self->{line_count}");
+		return defined $rv ? 1 # Defined but false signals "go to next line"
+			: $self->_error( "Error at line $self->{line_count}" );
 	}
 
 	# If we can't deal with the entire line, process char by char
 	while ( $rv = $self->_process_next_char ) {}
 	unless ( defined $rv ) {
-		PPI::Exception->throw("Error at line $self->{line_count}, character $self->{line_cursor}");
+		return $self->_error( "Error at line $self->{line_count}, character $self->{line_cursor}" );
 	}
 
 	# Trigger any action that needs to happen at the end of a line
 	$self->{class}->__TOKENIZER__on_line_end( $self );
 
 	# If there are no more source lines, then clean up
-	unless ( ref($self->{source}) eq 'ARRAY' and @{$self->{source}} ) {
+	if ( ref $self->{source} eq 'ARRAY' and ! @{$self->{source}} ) {
 		return $self->_clean_eof;
 	}
 
-	return 1;
+	# If we have any entries in the rawinput queue process it.
+	# This should happen at the END of this line, not the beginning of
+	# the next one, because Tokenizer->get_token, may retrieve the RawInput
+	# terminator and process it before we get a chance to rebless it from
+	# a bareword or a string that it was originally. Note also that
+	# _handle_raw_input has the same return conditions as this method.
+	$self->{rawinput_queue} ? $self->_handle_raw_input : 1;
 }
 
+# Read in raw input from the source
+# Returns 1 on success
+# Returns 0 on EOF
+# Returns undef on error
+sub _handle_raw_input {
+	my $self = shift;
+
+	# Is there a half finished token?
+	if ( defined $self->{token} ) {
+		if ( ref($self->{token}) eq 'PPI::Token::Whitespace' ) {
+			# Finish the whitespace token
+			$self->_finalize_token;
+		} else {
+			# This is just a little too complicated to tokenize.
+			# The Perl interpretor has the luxury of being able to
+			# destructively consume the input. We don't... so having
+			# a token that SPANS OVER a raw input is just silly, and
+			# too complicated for this little parser to turn back
+			# into something useful.
+			return $self->_error( "The code is too crufty for the tokenizer.\n"
+				. "Cannot have tokens that span across rawinput lines." );
+		}
+	}
+
+	while ( scalar @{$self->{rawinput_queue}} ) {
+		# Find the rawinput operator and terminator
+		my $position = shift @{$self->{rawinput_queue}};
+		my $operator = $self->{tokens}->[ $position ];
+		my $terminator = $self->{tokens}->[ $position + 1 ];
+
+		# Handle a whitespace gap between the operator and terminator
+		if ( ref($terminator) eq 'PPI::Token::Whitespace' ) {
+			$terminator = $self->{tokens}->[ $position + 2 ];
+		}
+
+		# Check the terminator, and get the termination string
+		my $tString;
+		if ( ref($terminator) eq 'PPI::Token::Word' ) {
+			$tString = $terminator->{content};
+		} elsif ( ref($terminator) =~ /^PPI::Token::Quote::(Single|Double)$/ ) {
+			$tString = $terminator->string;
+			return undef unless defined $tString;
+		} else {
+			return $self->_error( "Syntax error. The raw input << operator must be followed by a bare word, or a single or double quoted string" );
+		}
+		$tString .= "\n";
+
+		# Change the class of the terminator token to the appropriate one
+		$terminator->set_class( 'RawInput::Terminator' ) or return undef;
+
+		# Create the token
+		my $rawinput = PPI::Token::RawInput::String->new( '' ) or return undef;
+		$rawinput->{endString} = $tString;
+
+		# Add some extra links, so these will know where its other parts are
+		$rawinput->{_operator} = $operator;
+		$operator->{_string}   = $rawinput;
+
+		# Start looking at lines, and pull new ones until we find the
+		# termination string.
+		my $rv;
+		while ( $rv = $self->_fill_line ) {
+			# Add to the token
+			$rawinput->{content} .= $self->{line};
+
+			# Does the line match the termination string
+			if ( $self->{line} eq $tString ) {
+				# Done
+				push @{ $self->{tokens} }, $rawinput;
+				last;
+			}
+		}
+
+		# End of this rawinput
+		next if $rv;
+
+		# Pass on any error
+		return undef unless defined $rv;
+
+		# End of file. We are a bit more lenient on errors, so
+		# we will let this slip by without mention. In fact, it may
+		# well actually be legal.
+
+		# Finish the token
+		push @{ $self->{tokens} }, $rawinput if $rawinput->{content} ne '';
+		return 0;
+	}
+
+	# Clean up and return true
+	delete $self->{rawinput_queue};
+
+	1;
+}
 
 
 
@@ -568,32 +566,31 @@ sub _process_next_line {
 # Per-character processing methods
 
 # Process on a per-character basis.
-# Note that due the high number of times this gets
+# Note that due the the high number of times this gets
 # called, it has been fairly heavily in-lined, so the code
 # might look a bit ugly and duplicated.
 sub _process_next_char {
 	my $self = shift;
 
 	### FIXME - This checks for a screwed up condition that triggers
-	###         several warnings, amongst other things.
+	###         several warnings, amoungst other things.
 	if ( ! defined $self->{line_cursor} or ! defined $self->{line_length} ) {
 		# $DB::single = 1;
 		return undef;
 	}
 
-    $self->{line_cursor}++;
-    return 0 if $self->_at_line_end;
+	# Increment the counter and check for end of line
+	return 0 if ++$self->{line_cursor} >= $self->{line_length};
 
 	# Pass control to the token class
-	my $result;
-	unless ( $result = $self->{class}->__TOKENIZER__on_char( $self ) ) {
+	unless ( $_ = $self->{class}->__TOKENIZER__on_char( $self ) ) {
 		# undef is error. 0 is "Did stuff ourself, you don't have to do anything"
-		return defined $result ? 1 : undef;
+		return defined $_ ? 1 : undef;
 	}
 
 	# We will need the value of the current character
 	my $char = substr( $self->{line}, $self->{line_cursor}, 1 );
-	if ( $result eq '1' ) {
+	if ( $_ eq '1' ) {
 		# If __TOKENIZER__on_char returns 1, it is signaling that it thinks that
 		# the character is part of it.
 
@@ -601,32 +598,27 @@ sub _process_next_char {
 		if ( defined $self->{token} ) {
 			$self->{token}->{content} .= $char;
 		} else {
-			defined($self->{token} = $self->{class}->new($char)) or return undef;
+			$self->{token} = $self->{class}->new( $char ) or return undef;
 		}
 
 		return 1;
 	}
 
 	# We have been provided with the name of a class
-	if ( $self->{class} ne "PPI::Token::$result" ) {
+	if ( $self->{class} ne "PPI::Token::$_" ) {
 		# New class
-		$self->_new_token( $result, $char );
+		$self->_new_token( $_, $char );
 	} elsif ( defined $self->{token} ) {
 		# Same class as current
 		$self->{token}->{content} .= $char;
 	} else {
 		# Same class, but no current
-		defined($self->{token} = $self->{class}->new($char)) or return undef;
+		$self->{token} = $self->{class}->new( $char ) or return undef;
 	}
 
 	1;
 }
 
-sub _at_line_end {
-    my ($self) = @_;
-    return $self->{line_cursor} >= $self->{line_length};
-}
-
 
 
 
@@ -638,7 +630,7 @@ sub _at_line_end {
 # Returns the resulting parse class as a convenience.
 sub _finalize_token {
 	my $self = shift;
-	return $self->{class} unless defined $self->{token};
+	return $self->{class} unless $self->{token};
 
 	# Add the token to the token buffer
 	push @{ $self->{tokens} }, $self->{token};
@@ -649,23 +641,37 @@ sub _finalize_token {
 }
 
 # Creates a new token and sets it in the tokenizer
-# The defined() in here prevent a ton of calls to PPI::Util::TRUE
 sub _new_token {
 	my $self = shift;
-	# throw PPI::Exception() unless @_;
+	return undef unless @_;
 	my $class = substr( $_[0], 0, 12 ) eq 'PPI::Token::'
 		? shift : 'PPI::Token::' . shift;
 
 	# Finalize any existing token
-	$self->_finalize_token if defined $self->{token};
+	$self->_finalize_token if $self->{token};
 
 	# Create the new token and update the parse class
-	defined($self->{token} = $class->new($_[0])) or PPI::Exception->throw;
+	$self->{token} = $class->new($_[0]) or return undef;
 	$self->{class} = $class;
 
 	1;
 }
 
+# Changes the token class
+sub _set_token_class {
+	my $self = shift;
+	return $self->_error( "No token to change" ) unless $self->{token};
+
+	# Change the token class
+	$self->{token}->set_class( $_[0] )
+		or $self->_error( "Failed to change token class to '$_[0]'" );
+
+	# Update our parse class
+	$self->{class} = ref $self->{token};
+
+	1;
+}
+
 # At the end of the file, we need to clean up the results of the erroneous
 # space that we inserted at the beginning of the process.
 sub _clean_eof {
@@ -677,7 +683,7 @@ sub _clean_eof {
 	# Find the last token, and if it has no content, kill it.
 	# There appears to be some evidence that such "null tokens" are
 	# somehow getting created accidentally.
-	my $last_token = $self->{tokens}->[ -1 ];
+	my $last_token = $self->{tokens}->[ $#{$self->{tokens}} ];
 	unless ( length $last_token->{content} ) {
 		pop @{$self->{tokens}};
 	}
@@ -685,7 +691,7 @@ sub _clean_eof {
 	# Now, if the last character of the last token is a space we added,
 	# chop it off, deleting the token if there's nothing else left.
 	if ( $self->{source_eof_chop} ) {
-		$last_token = $self->{tokens}->[ -1 ];
+		$last_token = $self->{tokens}->[ $#{$self->{tokens}} ];
 		$last_token->{content} =~ s/ $//;
 		unless ( length $last_token->{content} ) {
 			# Popping token
@@ -708,166 +714,78 @@ sub _clean_eof {
 # Utility Methods
 
 # Context
-sub _last_token {
-	$_[0]->{tokens}->[-1];
-}
-
+sub _last_token { $_[0]->{tokens}->[-1] }
 sub _last_significant_token {
-	my $self   = shift;
+	my $self = shift;
 	my $cursor = $#{ $self->{tokens} };
 	while ( $cursor >= 0 ) {
 		my $token = $self->{tokens}->[$cursor--];
 		return $token if $token->significant;
 	}
-	return;
+
+	# Nothing...
+	PPI::Token::Whitespace->null;
 }
 
 # Get an array ref of previous significant tokens.
 # Like _last_significant_token except it gets more than just one token
-# Returns array with 0 to x entries
+# Returns array ref on success.
+# Returns 0 on not enough tokens
 sub _previous_significant_tokens {
-	my $self   = shift;
-	my $count  = shift || 1;
+	my $self = shift;
+	my $count = shift || 1;
 	my $cursor = $#{ $self->{tokens} };
 
-	my @tokens;
+	my ($token, @tokens);
 	while ( $cursor >= 0 ) {
-		my $token = $self->{tokens}->[$cursor--];
-		next if not $token->significant;
-		push @tokens, $token;
-		last if @tokens >= $count;
-	}
-
-	return @tokens;
-}
-
-my %OBVIOUS_CLASS = (
-	'PPI::Token::Symbol'              => 'operator',
-	'PPI::Token::Magic'               => 'operator',
-	'PPI::Token::Number'              => 'operator',
-	'PPI::Token::ArrayIndex'          => 'operator',
-	'PPI::Token::Quote::Double'       => 'operator',
-	'PPI::Token::Quote::Interpolate'  => 'operator',
-	'PPI::Token::Quote::Literal'      => 'operator',
-	'PPI::Token::Quote::Single'       => 'operator',
-	'PPI::Token::QuoteLike::Backtick' => 'operator',
-	'PPI::Token::QuoteLike::Command'  => 'operator',
-	'PPI::Token::QuoteLike::Readline' => 'operator',
-	'PPI::Token::QuoteLike::Regexp'   => 'operator',
-	'PPI::Token::QuoteLike::Words'    => 'operator',
-);
-
-my %OBVIOUS_CONTENT = (
-	'(' => 'operand',
-	'{' => 'operand',
-	'[' => 'operand',
-	';' => 'operand',
-	'}' => 'operator',
-);
-
-
-my %USUALLY_FORCES = map { $_ => 1 } qw( sub package use no );
-
-# Try to determine operator/operand context, if possible.
-# Returns "operator", "operand", or "" if unknown.
-sub _opcontext {
-	my $self   = shift;
-	my @tokens = $self->_previous_significant_tokens(1);
-	my $p0     = $tokens[0];
-	return '' if not $p0;
-	my $c0     = ref $p0;
-
-	# Map the obvious cases
-	return $OBVIOUS_CLASS{$c0}   if defined $OBVIOUS_CLASS{$c0};
-	return $OBVIOUS_CONTENT{$p0} if defined $OBVIOUS_CONTENT{$p0};
-
-	# Most of the time after an operator, we are an operand
-	return 'operand' if $p0->isa('PPI::Token::Operator');
-
-	# If there's NOTHING, it's operand
-	return 'operand' if $p0->content eq '';
-
-	# Otherwise, we don't know
-	return ''
-}
-
-# Assuming we are currently parsing the word 'x', return true
-# if previous tokens imply the x is an operator, false otherwise.
-sub _current_x_is_operator {
-	my ( $self ) = @_;
-	return if !@{$self->{tokens}};
-
-	my ($prev, $prevprev) = $self->_previous_significant_tokens(2);
-	return if !$prev;
-
-	return !$self->__current_token_is_forced_word if $prev->isa('PPI::Token::Word');
-
-	return (!$prev->isa('PPI::Token::Operator') || $X_CAN_FOLLOW_OPERATOR{$prev})
-		&& (!$prev->isa('PPI::Token::Structure') || $X_CAN_FOLLOW_STRUCTURE{$prev})
-		&& !$prev->isa('PPI::Token::Label')
-	;
-}
-
-
-# Assuming we are at the end of parsing the current token that could be a word,
-# a wordlike operator, or a version string, try to determine whether context
-# before or after it forces it to be a bareword. This method is only useful
-# during tokenization.
-sub __current_token_is_forced_word {
-	my ( $t, $word ) = @_;
-
-	# Check if forced by preceding tokens.
-
-	my ( $prev, $prevprev ) = $t->_previous_significant_tokens(2);
-	if ( !$prev ) {
-		pos $t->{line} = $t->{line_cursor};
-	}
-	else {
-		my $content = $prev->{content};
-
-		# We are forced if we are a method name.
-		# '->' will always be an operator, so we don't check its type.
-		return 1 if $content eq '->';
-
-		# If we are contained in a pair of curly braces, we are probably a
-		# forced bareword hash key. '{' is never a word or operator, so we
-		# don't check its type.
-		pos $t->{line} = $t->{line_cursor};
-		return 1 if $content eq '{' and $t->{line} =~ /\G\s*\}/gc;
-
-		# sub, package, use, and no all indicate that what immediately follows
-		# is a word not an operator or (in the case of sub and package) a
-		# version string.  However, we don't want to be fooled by 'package
-		# package v10' or 'use no v10'. We're a forced package unless we're
-		# preceded by 'package sub', in which case we're a version string.
-		# We also have to make sure that the sub/package/etc doing the forcing
-		# is not a method call.
-		if( $USUALLY_FORCES{$content}) {
-			return if defined $word and $word =~ /^v[0-9]+$/ and ( $content eq "use" or $content eq "no" );
-			return 1 if not $prevprev;
-			return 1 if not $USUALLY_FORCES{$prevprev->content} and $prevprev->content ne '->';
-			return;
+		$token = $self->{tokens}->[$cursor--];
+		if ( $token->significant ) {
+			push @tokens, $token;
+			return \@tokens if scalar @tokens >= $count;
 		}
 	}
-	# pos on $t->{line} is guaranteed to be set at this point.
 
-	# Check if forced by following tokens.
+	# Pad with empties
+	foreach ( 1 .. ($count - scalar @tokens) ) {
+		push @tokens, PPI::Token::Whitespace->null;
+	}
 
-	# If the word is followed by => it is probably a word, not a regex.
-	return 1 if $t->{line} =~ /\G\s*=>/gc;
-
-	# Otherwise we probably aren't forced
-	return '';
+	\@tokens;
 }
 
-sub _features {
-	my $self = shift;
-	return @_ ? $self->{features} = shift : $self->{features} || {};
+
+
+
+
+#####################################################################
+# Error Handling
+
+# Set the error message
+sub _error {
+	$errstr = $_[1];
+	undef;
 }
 
-sub _current_token_has_signatures_active {
-	my $self = shift;
-	return $self->{features}{signatures};
+# Clear the error message.
+# Returns the object as a convenience.
+sub _clear {
+	$errstr = '';
+	$_[0];
+}
+
+=pod
+
+=head2 errstr
+
+For any error that occurs, you can use the C<errstr>, as either
+a static or object method, to access the error message.
+
+If no error occurs for any particular action, C<errstr> will return false.
+
+=cut
+
+sub errstr {
+	$errstr;
 }
 
 1;
@@ -878,9 +796,9 @@ sub _current_token_has_signatures_active {
 
 =head2 How the Tokenizer Works
 
-Understanding the Tokenizer is not for the faint-hearted. It is by far
+Understanding the Tokenizer is not for the feint-hearted. It is by far
 the most complex and twisty piece of perl I've ever written that is actually
-still built properly and isn't a terrible spaghetti-like mess. In fact, you
+still built properly and isn't a terrible spagetti-like mess. In fact, you
 probably want to skip this section.
 
 But if you really want to understand, well then here goes.
@@ -889,7 +807,7 @@ But if you really want to understand, well then here goes.
 
 The Tokenizer starts by taking source in a variety of forms, sucking it
 all in and merging into one big string, and doing our own internal line
-split, using a "universal line separator" which allows the Tokenizer to
+split, using a "universal line seperator" which allows the Tokenizer to
 take source for any platform (and even supports a few known types of
 broken newlines caused by mixed mac/pc/*nix editor screw ups).
 
@@ -909,7 +827,7 @@ called in whatever token class we are currently in, which will examine the
 character at the current position, and handle it.
 
 As the handler methods in the various token classes are called, they
-build up an output token array for the source code.
+build up a output token array for the source code.
 
 Various parts of the Tokenizer use look-ahead, arbitrary-distance
 look-behind (although currently the maximum is three significant tokens),
@@ -949,7 +867,7 @@ recognise different "base" or "substrate" classes. When a Token such as a
 comment or a number is finalised by the tokenizer, it "falls back" to the
 base state.
 
-This allows proper tokenization of special areas such as __DATA__
+This allows proper tokenisation of special areas such as __DATA__
 and __END__ blocks, which also contain things like comments and POD,
 without allowing the creation of any significant Tokens inside these areas.
 
@@ -963,7 +881,7 @@ that is currently being built by the Tokenizer. For certain types, it
 can be manipulated and morphed and change class quite a bit while being
 assembled, as the Tokenizer's understanding of the token content changes.
 
-When the Tokenizer is confident that it has seen the end of the Token, it
+When the Tokeniser is confident that it has seen the end of the Token, it
 will be "finalized", which adds it to the output token array and resets
 the current class to that of the zone that we are currently in.
 
@@ -976,14 +894,14 @@ set to, without actually having accumulated any characters in the Token.
 =head2 Making It Faster
 
 As I'm sure you can imagine, calling several different methods for each
-character and running regexes and other complex heuristics made the first
+character and running regexs and other complex heuristics made the first
 fully working version of the tokenizer extremely slow.
 
 During testing, I created a metric to measure parsing speed called
 LPGC, or "lines per gigacycle" . A gigacycle is simple a billion CPU
 cycles on a typical single-core CPU, and so a Tokenizer running at
 "1000 lines per gigacycle" should generate around 1200 lines of tokenized
-code when running on a 1200 MHz processor.
+code when running on a 1200Mhz processor.
 
 The first working version of the tokenizer ran at only 350 LPGC, so to
 tokenize a typical large module such as L<ExtUtils::MakeMaker> took
@@ -1010,7 +928,7 @@ and a few other minor special cases.
 The second stage of the optimisation involved inlining a small
 number of critical methods that were repeated an extremely high number
 of times. Profiling suggested that there were about 1,000,000 individual
-method calls per gigacycle, and by cutting these by two thirds a significant
+method calls per gigacycle, and by cutting these by two thirds a signficant
 speed improvement was gained, in the order of about 50%.
 
 You may notice that many methods in the C<PPI::Tokenizer> code look
@@ -1021,7 +939,7 @@ versions of the parser was also removed, as it was determined that
 it was consuming around 15% of the CPU for the entire parser, while
 making the core more complicated.
 
-A judgment call was made that with the difficulties likely to be
+A judgement call was made that with the difficulties likely to be
 encountered with future planned enhancements, and given the relatively
 high cost involved, the statistics features would be removed from the
 Tokenizer.
@@ -1054,7 +972,7 @@ As it became evident that great speed increases were available by using
 this "skipping ahead" mechanism, a new handler method was added that
 explicitly handles the parsing of an entire token, where the structure
 of the token is relatively simple. Tokens such as symbols fit this case,
-as once we are passed the initial sigil and word char, we know that we
+as once we are passed the initial sygil and word char, we know that we
 can skip ahead and "complete" the rest of the token much more easily.
 
 A number of these have been added for most or possibly all of the common
@@ -1074,7 +992,7 @@ of the Lexer, and this has allowed the full parser to maintain around
 
 While it would be extraordinarily difficult to port all of the Tokenizer
 to C, work has started on a L<PPI::XS> "accelerator" package which acts as
-a separate and automatically-detected add-on to the main PPI package.
+a seperate and automatically-detected add-on to the main PPI package.
 
 L<PPI::XS> implements faster versions of a variety of functions scattered
 over the entire PPI codebase, from the Tokenizer Core, Quote Engine, and
@@ -1082,7 +1000,7 @@ various other places, and implements them identically in XS/C.
 
 In particular, the skip-ahead methods from the Quote Engine would appear
 to be extremely amenable to being done in C, and a number of other
-functions could be cherry-picked one at a time and implemented in C.
+functions could be cheryy-picked one at a time and implemented in C.
 
 Each method is heavily tested to ensure that the functionality is
 identical, and a versioning mechanism is included to ensure that if a
@@ -1097,15 +1015,15 @@ not replace that single method.
 
 =head1 SUPPORT
 
-See the L<support section|PPI/SUPPORT> in the main module.
+See the L<support section|PPI/SUPPORT> in the main module
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Adam Kennedy, L<http://ali.as/>, cpan@ali.as
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2011 Adam Kennedy.
+Copyright (c) 2001 - 2005 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
